@@ -40,7 +40,7 @@ from sickchill.update_manager import GitUpdateManager, SourceUpdateManager
 from sickchill.views.server_settings import SRWebServer
 
 # http://bugs.python.org/issue7980#msg221094
-THROWAWAY = datetime.datetime.strptime('20110101', '%Y%m%d')
+THROWAWAY = datetime.datetime.strptime("20110101", "%Y%m%d")
 
 signal.signal(signal.SIGINT, sickchill.start.sig_handler)
 signal.signal(signal.SIGTERM, sickchill.start.sig_handler)
@@ -59,7 +59,7 @@ class SickChill(object):
         # daemon constants
         self.run_as_daemon = False
         self.create_pid = False
-        self.pid_file = ''
+        self.pid_file = ""
 
         # web server constants
         self.web_server = None
@@ -76,11 +76,11 @@ class SickChill(object):
         Remove the Mako cache directory
         """
         try:
-            cache_folder = os.path.join(settings.CACHE_DIR, 'mako')
+            cache_folder = os.path.join(settings.CACHE_DIR, "mako")
             if os.path.isdir(cache_folder):
                 shutil.rmtree(cache_folder)
         except Exception:
-            logger.warning('Unable to remove the cache/mako directory!')
+            logger.warning("Unable to remove the cache/mako directory!")
 
     def start(self):
         """
@@ -91,23 +91,19 @@ class SickChill(object):
         settings.MY_NAME = os.path.basename(settings.MY_FULLNAME)
 
         settings.DATA_DIR = os.path.dirname(settings.PROG_DIR)
-        profile_path = str(Path.home().joinpath('sickchill').absolute())
+        profile_path = str(Path.home().joinpath("sickchill").absolute())
         if check_installed():
             settings.DATA_DIR = profile_path
 
         if settings.DATA_DIR != profile_path:
-            checks = [
-                'sickbeard.db',
-                'sickchill.db',
-                'config.ini'
-            ]
+            checks = ["sickbeard.db", "sickchill.db", "config.ini"]
             if not any([os.path.isfile(os.path.join(settings.DATA_DIR, check)) for check in checks]):
                 settings.DATA_DIR = profile_path
 
         settings.MY_ARGS = sys.argv[1:]
 
         # Rename the main thread
-        threading.currentThread().name = 'MAIN'
+        threading.currentThread().name = "MAIN"
 
         args = SickChillArgumentParser(settings.DATA_DIR).parse_args()
 
@@ -117,11 +113,11 @@ class SickChill(object):
 
         # Need console logging for SickChill.py and SickChill-console.exe
         settings.NO_RESIZE = args.noresize
-        self.console_logging = (not hasattr(sys, 'frozen')) or (settings.MY_NAME.lower().find('-console') > 0) and not args.quiet
+        self.console_logging = (not hasattr(sys, "frozen")) or (settings.MY_NAME.lower().find("-console") > 0) and not args.quiet
         self.no_launch = args.nolaunch
         self.forced_port = args.port
         if args.daemon:
-            self.run_as_daemon = platform.system() != 'Windows'
+            self.run_as_daemon = platform.system() != "Windows"
             self.console_logging = False
             self.no_launch = True
 
@@ -129,22 +125,22 @@ class SickChill(object):
         self.pid_file = args.pidfile
         if self.pid_file and os.path.exists(self.pid_file):
             # If the pid file already exists, SickChill may still be running, so exit
-            raise SystemExit('PID file: {0} already exists. Exiting.'.format(self.pid_file))
+            raise SystemExit("PID file: {0} already exists. Exiting.".format(self.pid_file))
 
         settings.DATA_DIR = os.path.abspath(args.datadir) if args.datadir else settings.DATA_DIR
-        settings.CONFIG_FILE = os.path.abspath(args.config) if args.config else os.path.join(settings.DATA_DIR, 'config.ini')
+        settings.CONFIG_FILE = os.path.abspath(args.config) if args.config else os.path.join(settings.DATA_DIR, "config.ini")
 
         # The pid file is only useful in daemon mode, make sure we can write the file properly
         if self.create_pid:
             if self.run_as_daemon:
                 pid_dir = os.path.dirname(self.pid_file)
                 if not os.access(pid_dir, os.F_OK):
-                    sys.exit('PID dir: {0} doesn\'t exist. Exiting.'.format(pid_dir))
+                    sys.exit("PID dir: {0} doesn't exist. Exiting.".format(pid_dir))
                 if not os.access(pid_dir, os.W_OK):
-                    raise SystemExit('PID dir: {0} must be writable (write permissions). Exiting.'.format(pid_dir))
+                    raise SystemExit("PID dir: {0} must be writable (write permissions). Exiting.".format(pid_dir))
             else:
                 if self.console_logging:
-                    sys.stdout.write('Not running in daemon mode. PID file creation disabled.\n')
+                    sys.stdout.write("Not running in daemon mode. PID file creation disabled.\n")
                 self.create_pid = False
 
         # Make sure that we can create the data dir
@@ -152,33 +148,33 @@ class SickChill(object):
             try:
                 os.makedirs(settings.DATA_DIR, 0o744)
             except os.error:
-                raise SystemExit('Unable to create data directory: {0}'.format(settings.DATA_DIR))
+                raise SystemExit("Unable to create data directory: {0}".format(settings.DATA_DIR))
 
         # Make sure we can write to the data dir
         if not os.access(settings.DATA_DIR, os.W_OK):
-            raise SystemExit('Data directory must be writeable: {0}'.format(settings.DATA_DIR))
+            raise SystemExit("Data directory must be writeable: {0}".format(settings.DATA_DIR))
 
         # Make sure we can write to the config file
         if not os.access(settings.CONFIG_FILE, os.W_OK):
             if os.path.isfile(settings.CONFIG_FILE):
-                raise SystemExit('Config file must be writeable: {0}'.format(settings.CONFIG_FILE))
+                raise SystemExit("Config file must be writeable: {0}".format(settings.CONFIG_FILE))
             elif not os.access(os.path.dirname(settings.CONFIG_FILE), os.W_OK):
-                raise SystemExit('Config file root dir must be writeable: {0}'.format(os.path.dirname(settings.CONFIG_FILE)))
+                raise SystemExit("Config file root dir must be writeable: {0}".format(os.path.dirname(settings.CONFIG_FILE)))
 
         os.chdir(settings.DATA_DIR)
 
         # Check if we need to perform a restore first
-        restore_dir = os.path.join(settings.DATA_DIR, 'restore')
+        restore_dir = os.path.join(settings.DATA_DIR, "restore")
         if os.path.exists(restore_dir):
             success = self.restore_db(restore_dir, settings.DATA_DIR)
             if self.console_logging:
-                sys.stdout.write('Restore: restoring DB and config.ini {0}!\n'.format(('FAILED', 'SUCCESSFUL')[success]))
+                sys.stdout.write("Restore: restoring DB and config.ini {0}!\n".format(("FAILED", "SUCCESSFUL")[success]))
 
         # Load the config and publish it to the oldbeard package
         if self.console_logging and not os.path.isfile(settings.CONFIG_FILE):
-            sys.stdout.write('Unable to find {0}, all settings will be default!\n'.format(settings.CONFIG_FILE))
+            sys.stdout.write("Unable to find {0}, all settings will be default!\n".format(settings.CONFIG_FILE))
 
-        settings.CFG = ConfigObj(settings.CONFIG_FILE, encoding='UTF-8', indent_type='  ')
+        settings.CFG = ConfigObj(settings.CONFIG_FILE, encoding="UTF-8", indent_type="  ")
 
         if self.run_as_daemon:
             self.daemonize()
@@ -192,7 +188,7 @@ class SickChill(object):
         # Build from the DB to start with
         self.load_shows_from_db()
 
-        logger.info('Starting SickChill [{branch}] using \'{config}\''.format(branch=settings.BRANCH, config=settings.CONFIG_FILE))
+        logger.info("Starting SickChill [{branch}] using '{config}'".format(branch=settings.BRANCH, config=settings.CONFIG_FILE))
 
         self.clear_cache()
 
@@ -201,11 +197,13 @@ class SickChill(object):
 
         web_options = {}
         if self.forced_port:
-            logger.info('Forcing web server to port {port}'.format(port=self.forced_port))
+            logger.info("Forcing web server to port {port}".format(port=self.forced_port))
             self.start_port = self.forced_port
-            web_options.update({
-                'port': int(self.start_port),
-            })
+            web_options.update(
+                {
+                    "port": int(self.start_port),
+                }
+            )
         else:
             self.start_port = settings.WEB_PORT
 
@@ -231,7 +229,7 @@ class SickChill(object):
 
         # Launch browser
         if settings.LAUNCH_BROWSER and not (self.no_launch or self.run_as_daemon):
-            sickchill.start.launchBrowser('https' if settings.ENABLE_HTTPS else 'http', self.start_port, settings.WEB_ROOT)
+            sickchill.start.launchBrowser("https" if settings.ENABLE_HTTPS else "http", self.start_port, settings.WEB_ROOT)
 
         # main loop
         while True:
@@ -250,8 +248,7 @@ class SickChill(object):
             if pid != 0:
                 os._exit(0)
         except OSError as error:
-            sys.stderr.write('fork #1 failed: {error_num}: {error_message}\n'.format
-                             (error_num=error.errno, error_message=error.strerror))
+            sys.stderr.write("fork #1 failed: {error_num}: {error_message}\n".format(error_num=error.errno, error_message=error.strerror))
             sys.exit(1)
 
         os.setsid()  # @UndefinedVariable - only available in UNIX
@@ -269,35 +266,36 @@ class SickChill(object):
             if pid != 0:
                 os._exit(0)
         except OSError as error:
-            sys.stderr.write('fork #2 failed: Error {error_num}: {error_message}\n'.format
-                             (error_num=error.errno, error_message=error.strerror))
+            sys.stderr.write("fork #2 failed: Error {error_num}: {error_message}\n".format(error_num=error.errno, error_message=error.strerror))
             sys.exit(1)
 
         # Write pid
         if self.create_pid:
             pid = os.getpid()
-            logger.info('Writing PID: {pid} to {filename}'.format(pid=pid, filename=self.pid_file))
+            logger.info("Writing PID: {pid} to {filename}".format(pid=pid, filename=self.pid_file))
 
             try:
-                with os.fdopen(os.open(self.pid_file, os.O_CREAT | os.O_WRONLY, 0o644), 'w') as f_pid:
-                    f_pid.write('{0}\n'.format(pid))
+                with os.fdopen(os.open(self.pid_file, os.O_CREAT | os.O_WRONLY, 0o644), "w") as f_pid:
+                    f_pid.write("{0}\n".format(pid))
             except EnvironmentError as error:
-                logger.log_error_and_exit('Unable to write PID file: {filename} Error {error_num}: {error_message}'.format
-                                          (filename=self.pid_file, error_num=error.errno, error_message=error.strerror))
+                logger.log_error_and_exit(
+                    "Unable to write PID file: {filename} Error {error_num}: {error_message}".format(
+                        filename=self.pid_file, error_num=error.errno, error_message=error.strerror
+                    )
+                )
 
         # Redirect all output
         sys.stdout.flush()
         sys.stderr.flush()
 
-
-        devnull = getattr(os, 'devnull', '/dev/null')
+        devnull = getattr(os, "devnull", "/dev/null")
         stdin = open(devnull)
-        stdout = open(devnull, 'a+')
-        stderr = open(devnull, 'a+')
+        stdout = open(devnull, "a+")
+        stderr = open(devnull, "a+")
 
-        os.dup2(stdin.fileno(), getattr(sys.stdin, 'device', sys.stdin).fileno())
-        os.dup2(stdout.fileno(), getattr(sys.stdout, 'device', sys.stdout).fileno())
-        os.dup2(stderr.fileno(), getattr(sys.stderr, 'device', sys.stderr).fileno())
+        os.dup2(stdin.fileno(), getattr(sys.stdin, "device", sys.stdin).fileno())
+        os.dup2(stdout.fileno(), getattr(sys.stdout, "device", sys.stdout).fileno())
+        os.dup2(stderr.fileno(), getattr(sys.stderr, "device", sys.stderr).fileno())
 
     @staticmethod
     def remove_pid_file(pid_file):
@@ -320,20 +318,19 @@ class SickChill(object):
         """
         Populates the showList with shows from the database
         """
-        logger.debug('Loading initial show list')
+        logger.debug("Loading initial show list")
 
         main_db_con = db.DBConnection()
-        sql_results = main_db_con.select('SELECT indexer, indexer_id, location FROM tv_shows;')
+        sql_results = main_db_con.select("SELECT indexer, indexer_id, location FROM tv_shows;")
 
         settings.showList = []
         for sql_show in sql_results:
             try:
-                cur_show = TVShow(sql_show['indexer'], sql_show['indexer_id'])
+                cur_show = TVShow(sql_show["indexer"], sql_show["indexer_id"])
                 cur_show.nextEpisode()
                 settings.showList.append(cur_show)
             except Exception as error:
-                logger.exception('There was an error creating the show in {0}: Error {1}'.format
-                           (sql_show['location'], error))
+                logger.exception("There was an error creating the show in {0}: Error {1}".format(sql_show["location"], error))
                 logger.debug(traceback.format_exc())
 
     @staticmethod
@@ -346,13 +343,13 @@ class SickChill(object):
         :return:
         """
         try:
-            files_list = ['sickbeard.db', 'sickchill.db', 'config.ini', 'failed.db', 'cache.db']
+            files_list = ["sickbeard.db", "sickchill.db", "config.ini", "failed.db", "cache.db"]
             for filename in files_list:
                 src_file = os.path.join(src_dir, filename)
                 dst_file = os.path.join(dst_dir, filename)
-                bak_file = os.path.join(dst_dir, '{0}.bak-{1}'.format(filename, datetime.datetime.now().strftime('%Y%m%d_%H%M%S')))
-                sickchill_db = os.path.join(dst_dir, 'sickchill.db')
-                sickbeard_db = os.path.join(src_dir, 'sickbeard.db')
+                bak_file = os.path.join(dst_dir, "{0}.bak-{1}".format(filename, datetime.datetime.now().strftime("%Y%m%d_%H%M%S")))
+                sickchill_db = os.path.join(dst_dir, "sickchill.db")
+                sickbeard_db = os.path.join(src_dir, "sickbeard.db")
                 if os.path.isfile(src_file):
                     if src_file == sickbeard_db:
                         dst_file = sickchill_db
@@ -361,8 +358,8 @@ class SickChill(object):
                         shutil.move(dst_file, bak_file)
                     shutil.move(src_file, dst_file)
 
-            sickbeard_db = os.path.join(dst_dir, 'sickbeard.db')
-            sickchill_db = os.path.join(dst_dir, 'sickchill.db')
+            sickbeard_db = os.path.join(dst_dir, "sickbeard.db")
+            sickchill_db = os.path.join(dst_dir, "sickchill.db")
             if os.path.isfile(sickbeard_db) and not os.path.isfile(sickchill_db):
                 shutil.move(sickbeard_db, sickchill_db)
 
@@ -382,7 +379,7 @@ class SickChill(object):
 
             # shutdown web server
             if self.web_server:
-                logger.info('Shutting down Tornado')
+                logger.info("Shutting down Tornado")
                 self.web_server.shutdown()
 
                 try:
@@ -397,21 +394,12 @@ class SickChill(object):
                 self.remove_pid_file(self.pid_file)
 
             if event == sickchill.oldbeard.event_queue.Events.SystemEvent.RESTART:
-                install_type = settings.versionCheckScheduler.action.install_type
-
-                popen_list = []
-
-                if install_type in ('git', 'source'):
-                    popen_list = [sys.executable, settings.MY_FULLNAME]
-                elif install_type == 'win':
-                    logger.exception('You are using a binary Windows build of SickChill. '
-                               'Please switch to using git.')
-
+                popen_list = [sys.executable, settings.MY_FULLNAME]
                 if popen_list and not settings.NO_RESTART:
                     popen_list += settings.MY_ARGS
-                    if '--nolaunch' not in popen_list:
-                        popen_list += ['--nolaunch']
-                    logger.info('Restarting SickChill with {options}'.format(options=popen_list))
+                    if "--nolaunch" not in popen_list:
+                        popen_list += ["--nolaunch"]
+                    logger.info("Restarting SickChill with {options}".format(options=popen_list))
                     # shutdown the logger to make sure it's released the logfile BEFORE it restarts SR.
                     logger.shutdown()
                     subprocess.Popen(popen_list, cwd=os.getcwd(), universal_newlines=True)
@@ -432,41 +420,41 @@ class SickChill(object):
             def run_git(updater, cmd):
                 stdout_, stderr_, exit_status = updater._run_git(updater._git_path, cmd)
                 if not exit_status == 0:
-                    print('Failed to run command: {0} {1}'.format(updater._git_path, cmd))
+                    print("Failed to run command: {0} {1}".format(updater._git_path, cmd))
                     return False
                 else:
                     return True
 
             updater = GitUpdateManager()
-            if not run_git(updater, 'config remote.origin.url https://github.com/SickChill/SickChill.git'):
+            if not run_git(updater, "config remote.origin.url https://github.com/SickChill/SickChill.git"):
                 return False
-            if not run_git(updater, 'fetch origin --prune'):
+            if not run_git(updater, "fetch origin --prune"):
                 return False
-            if not run_git(updater, 'checkout master'):
+            if not run_git(updater, "checkout master"):
                 return False
-            if not run_git(updater, 'reset --hard origin/master'):
+            if not run_git(updater, "reset --hard origin/master"):
                 return False
 
             return True
 
-        if os.path.isdir(os.path.join(os.path.dirname(settings.PROG_DIR), '.git')):  # update with git
-            print('Forcing SickChill to update using git...')
+        if os.path.isdir(os.path.join(os.path.dirname(settings.PROG_DIR), ".git")):  # update with git
+            print("Forcing SickChill to update using git...")
             result = update_with_git()
             if result:
-                print('Successfully updated to latest commit. You may now run SickChill normally.')
+                print("Successfully updated to latest commit. You may now run SickChill normally.")
                 return True
             else:
-                print('Error while trying to force an update using git.')
+                print("Error while trying to force an update using git.")
 
-        print('Forcing SickChill to update using source...')
+        print("Forcing SickChill to update using source...")
         if not SourceUpdateManager().update():
-            print('Failed to force an update.')
+            print("Failed to force an update.")
             return False
 
-        print('Successfully updated to latest commit. You may now run SickChill normally.')
+        print("Successfully updated to latest commit. You may now run SickChill normally.")
         return True
 
 
-if __name__ == '__main__':
+if __name__ == "__main__":
     # start SickChill
     SickChill().start()
