@@ -16,23 +16,29 @@ from . import db, helpers, naming
 # Address poor support for scgi over unix domain sockets
 # this is not nicely handled by python currently
 # http://bugs.python.org/issue23636
-parse.uses_netloc.append('scgi')
+parse.uses_netloc.append("scgi")
 
-naming_ep_type = ("%(seasonnumber)dx%(episodenumber)02d",
-                  "s%(seasonnumber)02de%(episodenumber)02d",
-                  "S%(seasonnumber)02dE%(episodenumber)02d",
-                  "%(seasonnumber)02dx%(episodenumber)02d")
+naming_ep_type = (
+    "%(seasonnumber)dx%(episodenumber)02d",
+    "s%(seasonnumber)02de%(episodenumber)02d",
+    "S%(seasonnumber)02dE%(episodenumber)02d",
+    "%(seasonnumber)02dx%(episodenumber)02d",
+)
 
-sports_ep_type = ("%(seasonnumber)dx%(episodenumber)02d",
-                  "s%(seasonnumber)02de%(episodenumber)02d",
-                  "S%(seasonnumber)02dE%(episodenumber)02d",
-                  "%(seasonnumber)02dx%(episodenumber)02d")
+sports_ep_type = (
+    "%(seasonnumber)dx%(episodenumber)02d",
+    "s%(seasonnumber)02de%(episodenumber)02d",
+    "S%(seasonnumber)02dE%(episodenumber)02d",
+    "%(seasonnumber)02dx%(episodenumber)02d",
+)
 
 naming_ep_type_text = ("1x02", "s01e02", "S01E02", "01x02")
 
-naming_multi_ep_type = {0: ["-%(episodenumber)02d"] * len(naming_ep_type),
-                        1: [" - " + x for x in naming_ep_type],
-                        2: [x + "%(episodenumber)02d" for x in ("x", "e", "E", "x")]}
+naming_multi_ep_type = {
+    0: ["-%(episodenumber)02d"] * len(naming_ep_type),
+    1: [" - " + x for x in naming_ep_type],
+    2: [x + "%(episodenumber)02d" for x in ("x", "e", "E", "x")],
+}
 naming_multi_ep_type_text = ("extend", "duplicate", "repeat")
 
 naming_sep_type = (" - ", " ")
@@ -46,8 +52,8 @@ def change_https_cert(https_cert):
     :param https_cert: path to the new certificate file
     :return: True on success, False on failure
     """
-    if https_cert == '':
-        settings.HTTPS_CERT = ''
+    if https_cert == "":
+        settings.HTTPS_CERT = ""
         return True
 
     if os.path.normpath(settings.HTTPS_CERT) != os.path.normpath(https_cert):
@@ -68,7 +74,7 @@ def change_https_key(https_key):
     :return: True on success, False on failure
     """
     if not https_key:
-        settings.HTTPS_KEY = ''
+        settings.HTTPS_KEY = ""
         return True
 
     if os.path.normpath(settings.HTTPS_KEY) != os.path.normpath(https_key):
@@ -119,18 +125,22 @@ def change_unrar_tool(unrar_tool, unar_tool, bsdtar_tool):
     rarfile.UNAR_TOOL = _unar_tool
     rarfile.BSDTAR_TOOL = _bsdtar_tool
 
-    if platform.system() == 'Windows':
+    if platform.system() == "Windows":
         # Look for WinRAR installations
         found = False
-        winrar_path = 'WinRAR\\UnRAR.exe'
+        winrar_path = "WinRAR\\UnRAR.exe"
         # Make a set of unique paths to check from existing environment variables
         check_locations = {
-            os.path.join(location, winrar_path) for location in (
-                os.environ.get("ProgramW6432"), os.environ.get("ProgramFiles(x86)"),
-                os.environ.get("ProgramFiles"), re.sub(r'\s?\(x86\)', '', os.environ["ProgramFiles"])
-            ) if location
+            os.path.join(location, winrar_path)
+            for location in (
+                os.environ.get("ProgramW6432"),
+                os.environ.get("ProgramFiles(x86)"),
+                os.environ.get("ProgramFiles"),
+                re.sub(r"\s?\(x86\)", "", os.environ["ProgramFiles"]),
+            )
+            if location
         }
-        check_locations.add(os.path.join(settings.DATA_DIR, 'unrar\\unrar.exe'))
+        check_locations.add(os.path.join(settings.DATA_DIR, "unrar\\unrar.exe"))
 
         for check in check_locations:
             if os.path.isfile(check):
@@ -142,13 +152,13 @@ def change_unrar_tool(unrar_tool, unar_tool, bsdtar_tool):
                 except rarfile.RarCannotExec:
                     pass
 
-        logger.info('Trying to download unrar.exe and set the path')
-        unrar_store = os.path.join(settings.DATA_DIR, 'unrar')  # ./unrar (folder)
-        unrar_zip = os.path.join(settings.DATA_DIR, 'unrar_win.zip')  # file download
+        logger.info("Trying to download unrar.exe and set the path")
+        unrar_store = os.path.join(settings.DATA_DIR, "unrar")  # ./unrar (folder)
+        unrar_zip = os.path.join(settings.DATA_DIR, "unrar_win.zip")  # file download
 
-        if (helpers.download_file(
-            "https://sickchill.github.io/unrar/unrar_win.zip", filename=unrar_zip, session=helpers.make_session()
-        ) and helpers.extractZip(archive=unrar_zip, targetDir=unrar_store)):
+        if helpers.download_file("https://sickchill.github.io/unrar/unrar_win.zip", filename=unrar_zip, session=helpers.make_session()) and helpers.extractZip(
+            archive=unrar_zip, targetDir=unrar_store
+        ):
             try:
                 os.remove(unrar_zip)
             except OSError as e:
@@ -159,12 +169,12 @@ def change_unrar_tool(unrar_tool, unar_tool, bsdtar_tool):
                 rarfile.UNRAR_TOOL = check
                 rarfile.tool_setup()
                 settings.UNRAR_TOOL = check
-                logger.info('Successfully downloaded unrar.exe and set as unrar tool')
+                logger.info("Successfully downloaded unrar.exe and set as unrar tool")
                 return True
             except (rarfile.RarCannotExec, rarfile.RarExecError, OSError, IOError):
-                logger.info('Sorry, unrar was not set up correctly. Try installing WinRAR and make sure it is on the system PATH')
+                logger.info("Sorry, unrar was not set up correctly. Try installing WinRAR and make sure it is on the system PATH")
         else:
-            logger.info('Unable to download unrar.exe')
+            logger.info("Unable to download unrar.exe")
 
     # These must always be set to something before returning
     settings.UNRAR_TOOL = rarfile.UNRAR_TOOL = _unrar_tool
@@ -176,7 +186,7 @@ def change_unrar_tool(unrar_tool, unar_tool, bsdtar_tool):
         return True
     except rarfile.RarCannotExec:
         if settings.UNPACK == settings.UNPACK_PROCESS_CONTENTS:
-            logger.info(_('Disabling UNPACK setting because no unrar/unar/bsdtar is found and accessible in the path or setting.'))
+            logger.info(_("Disabling UNPACK setting because no unrar/unar/bsdtar is found and accessible in the path or setting."))
             settings.UNPACK = settings.UNPACK_DISABLED
         return False
 
@@ -189,7 +199,7 @@ def change_sickchill_background(background):
     :return: True on success, False on failure
     """
     if not background:
-        settings.SICKCHILL_BACKGROUND_PATH = ''
+        settings.SICKCHILL_BACKGROUND_PATH = ""
         return True
 
     background = os.path.normpath(background)
@@ -210,14 +220,14 @@ def change_custom_css(new_css):
     :return: True on success, False on failure
     """
     if not new_css:
-        settings.CUSTOM_CSS_PATH = ''
+        settings.CUSTOM_CSS_PATH = ""
         return True
 
     new_css = os.path.normpath(new_css)
     if not os.path.isfile(new_css):
         logger.info("Custom css file does not exist: {0}".format(new_css))
         return False
-    if not new_css.endswith('css'):
+    if not new_css.endswith("css"):
         logger.info("Custom css file should have the .css extension: {0}".format(new_css))
         return False
 
@@ -232,8 +242,8 @@ def change_nzb_dir(nzb_dir):
     :param nzb_dir: New NZB Folder location
     :return: True on success, False on failure
     """
-    if nzb_dir == '':
-        settings.NZB_DIR = ''
+    if nzb_dir == "":
+        settings.NZB_DIR = ""
         return True
 
     if os.path.normpath(settings.NZB_DIR) != os.path.normpath(nzb_dir):
@@ -253,8 +263,8 @@ def change_torrent_dir(torrent_dir):
     :param torrent_dir: New torrent directory
     :return: True on success, False on failure
     """
-    if torrent_dir == '':
-        settings.TORRENT_DIR = ''
+    if torrent_dir == "":
+        settings.TORRENT_DIR = ""
         return True
 
     if os.path.normpath(settings.TORRENT_DIR) != os.path.normpath(torrent_dir):
@@ -274,8 +284,8 @@ def change_tv_download_dir(tv_download_dir):
     :param tv_download_dir: New tv download directory
     :return: True on success, False on failure
     """
-    if tv_download_dir == '':
-        settings.TV_DOWNLOAD_DIR = ''
+    if tv_download_dir == "":
+        settings.TV_DOWNLOAD_DIR = ""
         return True
 
     if os.path.normpath(settings.TV_DOWNLOAD_DIR) != os.path.normpath(tv_download_dir):
@@ -295,13 +305,12 @@ def change_unpack_dir(unpack_dir):
     :param unpack_dir: New unpack directory
     :return: True on success, False on failure
     """
-    if unpack_dir == '':
-        settings.UNPACK_DIR = ''
+    if unpack_dir == "":
+        settings.UNPACK_DIR = ""
         return True
 
     if os.path.normpath(settings.UNPACK_DIR) != os.path.normpath(unpack_dir):
-        if bool(settings.ROOT_DIRS) and \
-                any(helpers.is_subdirectory(unpack_dir, rd) for rd in settings.ROOT_DIRS.split('|')[1:]):
+        if bool(settings.ROOT_DIRS) and any(helpers.is_subdirectory(unpack_dir, rd) for rd in settings.ROOT_DIRS.split("|")[1:]):
             # don't change if it's in any of the TV root directories
             logger.info("Unable to change unpack directory to a sub-directory of a TV root dir")
             return False
@@ -400,7 +409,7 @@ def change_subtitle_finder_frequency(subtitles_finder_frequency):
 
     :param subtitles_finder_frequency: New frequency
     """
-    if subtitles_finder_frequency == '' or subtitles_finder_frequency is None:
+    if subtitles_finder_frequency == "" or subtitles_finder_frequency is None:
         subtitles_finder_frequency = 1
 
     settings.SUBTITLES_FINDER_FREQUENCY = try_int(subtitles_finder_frequency, 1)
@@ -554,7 +563,7 @@ def checkbox_to_value(option, value_on=True, value_off=False):
     if isinstance(option, str):
         option = option.strip().lower()
 
-    if option in (True, 'on', 'true', value_on) or try_int(option) > 0:
+    if option in (True, "on", "true", value_on) or try_int(option) > 0:
         return value_on
 
     return value_off
@@ -570,24 +579,24 @@ def clean_host(host, default_port=None):
 
     if host:
 
-        match_host_port = re.search(r'(?:http.*://)?(?P<host>[^:/]+).?(?P<port>[0-9]*).*', host)
+        match_host_port = re.search(r"(?:http.*://)?(?P<host>[^:/]+).?(?P<port>[0-9]*).*", host)
 
-        cleaned_host = match_host_port.group('host')
-        cleaned_port = match_host_port.group('port')
+        cleaned_host = match_host_port.group("host")
+        cleaned_port = match_host_port.group("port")
 
         if cleaned_host:
 
             if cleaned_port:
-                host = cleaned_host + ':' + cleaned_port
+                host = cleaned_host + ":" + cleaned_port
 
             elif default_port:
-                host = cleaned_host + ':' + str(default_port)
+                host = cleaned_host + ":" + str(default_port)
 
             else:
                 host = cleaned_host
 
         else:
-            host = ''
+            host = ""
 
     return host
 
@@ -607,7 +616,7 @@ def clean_hosts(hosts, default_port=None):
         if cleaned_host:
             cleaned_hosts.append(cleaned_host)
 
-    cleaned_hosts = ",".join(cleaned_hosts) if cleaned_hosts else ''
+    cleaned_hosts = ",".join(cleaned_hosts) if cleaned_hosts else ""
 
     return cleaned_hosts
 
@@ -621,17 +630,17 @@ def clean_url(url):
     if url and url.strip():
         url = xhtml_unescape(url.strip())
 
-        if '://' not in url:
-            url = '//' + url
+        if "://" not in url:
+            url = "//" + url
 
-        scheme, netloc, path, query, fragment = parse.urlsplit(url, 'http')
+        scheme, netloc, path, query, fragment = parse.urlsplit(url, "http")
         if not path:
-            path += '/'
+            path += "/"
 
         cleaned_url = parse.urlunsplit((scheme, netloc, path, query, fragment))
 
     else:
-        cleaned_url = ''
+        cleaned_url = ""
 
     return cleaned_url
 
@@ -676,13 +685,13 @@ def check_setting_int(config, cfg_name, item_name, def_val=0, min_val=None, max_
     :rtype: int
     """
     if not isinstance(def_val, int):
-        logger.error("{dom}:{key} default value is not the correct type. Expected {t}, got {dt}".format(dom=cfg_name, key=item_name, t='int', dt=type(def_val)))
+        logger.error("{dom}:{key} default value is not the correct type. Expected {t}, got {dt}".format(dom=cfg_name, key=item_name, t="int", dt=type(def_val)))
 
     if not (min_val is None or isinstance(min_val, int)):
-        logger.error("{dom}:{key} min_val value is not the correct type. Expected {t}, got {dt}".format(dom=cfg_name, key=item_name, t='int', dt=type(min_val)))
+        logger.error("{dom}:{key} min_val value is not the correct type. Expected {t}, got {dt}".format(dom=cfg_name, key=item_name, t="int", dt=type(min_val)))
 
     if not (max_val is None or isinstance(max_val, int)):
-        logger.error("{dom}:{key} max_val value is not the correct type. Expected {t}, got {dt}".format(dom=cfg_name, key=item_name, t='int', dt=type(max_val)))
+        logger.error("{dom}:{key} max_val value is not the correct type. Expected {t}, got {dt}".format(dom=cfg_name, key=item_name, t="int", dt=type(max_val)))
 
     try:
         if not (check_section(config, cfg_name) and check_section(config[cfg_name], item_name)):
@@ -740,13 +749,19 @@ def check_setting_float(config, cfg_name, item_name, def_val=0.0, min_val=None,
     :rtype: float
     """
     if not isinstance(def_val, float):
-        logger.error("{dom}:{key} default value is not the correct type. Expected {t}, got {dt}".format(dom=cfg_name, key=item_name, t='float', dt=type(def_val)))
+        logger.error(
+            "{dom}:{key} default value is not the correct type. Expected {t}, got {dt}".format(dom=cfg_name, key=item_name, t="float", dt=type(def_val))
+        )
 
     if not (min_val is None or isinstance(min_val, float)):
-        logger.error("{dom}:{key} min_val value is not the correct type. Expected {t}, got {dt}".format(dom=cfg_name, key=item_name, t='float', dt=type(min_val)))
+        logger.error(
+            "{dom}:{key} min_val value is not the correct type. Expected {t}, got {dt}".format(dom=cfg_name, key=item_name, t="float", dt=type(min_val))
+        )
 
     if not (max_val is None or isinstance(max_val, float)):
-        logger.error("{dom}:{key} max_val value is not the correct type. Expected {t}, got {dt}".format(dom=cfg_name, key=item_name, t='float', dt=type(max_val)))
+        logger.error(
+            "{dom}:{key} max_val value is not the correct type. Expected {t}, got {dt}".format(dom=cfg_name, key=item_name, t="float", dt=type(max_val))
+        )
 
     try:
         if not (check_section(config, cfg_name) and check_section(config[cfg_name], item_name)):
@@ -775,7 +790,7 @@ def check_setting_float(config, cfg_name, item_name, def_val=0.0, min_val=None,
 ################################################################################
 # check_setting_str                                                            #
 ################################################################################
-def check_setting_str(config, cfg_name, item_name, def_val=str(''), silent=True, censor_log=False):
+def check_setting_str(config, cfg_name, item_name, def_val=str(""), silent=True, censor_log=False):
     """
     Checks config setting of string types
 
@@ -793,10 +808,12 @@ def check_setting_str(config, cfg_name, item_name, def_val=str(''), silent=True,
     :rtype: str
     """
     if not isinstance(def_val, str):
-        logger.error("{dom}:{key} default value is not the correct type. Expected {t}, got {dt}".format(dom=cfg_name, key=item_name, t='string', dt=type(def_val)))
+        logger.error(
+            "{dom}:{key} default value is not the correct type. Expected {t}, got {dt}".format(dom=cfg_name, key=item_name, t="string", dt=type(def_val))
+        )
 
     # For passwords you must include the word `password` in the item_name and add `helpers.encrypt(ITEM_NAME, ENCRYPTION_VERSION)` in save_config()
-    encryption_version = (0, settings.ENCRYPTION_VERSION)['password' in item_name]
+    encryption_version = (0, settings.ENCRYPTION_VERSION)["password" in item_name]
 
     try:
         if not (check_section(config, cfg_name) and item_name in config[cfg_name]):
@@ -813,7 +830,7 @@ def check_setting_str(config, cfg_name, item_name, def_val=str(''), silent=True,
 
         config[cfg_name][item_name] = helpers.encrypt(my_val, encryption_version)
 
-    if (censor_log or (cfg_name, item_name) in logger.censored_items.items()) and not item_name.endswith('custom_url'):
+    if (censor_log or (cfg_name, item_name) in logger.censored_items.items()) and not item_name.endswith("custom_url"):
         logger.censored_items[cfg_name, item_name] = my_val
 
     if not silent:
@@ -843,8 +860,9 @@ def check_setting_bool(config, cfg_name, item_name, def_val=False, silent=True):
     """
     try:
         if not isinstance(def_val, bool):
-            logger.error("{dom}:{key} default value is not the correct type. Expected {t}, got {dt}".format(
-                dom=cfg_name, key=item_name, t='bool', dt=type(def_val)))
+            logger.error(
+                "{dom}:{key} default value is not the correct type. Expected {t}, got {dt}".format(dom=cfg_name, key=item_name, t="bool", dt=type(def_val))
+            )
 
         if not (check_section(config, cfg_name) and item_name in config[cfg_name]):
             raise ValueError
@@ -879,21 +897,21 @@ class ConfigMigrator(object):
         self.config_obj = config_obj
 
         # check the version of the config
-        self.config_version = check_setting_int(config_obj, 'General', 'config_version', settings.CONFIG_VERSION)
+        self.config_version = check_setting_int(config_obj, "General", "config_version", settings.CONFIG_VERSION)
         self.expected_config_version = settings.CONFIG_VERSION
         self.migration_names = {
-            1: 'Custom naming',
-            2: 'Sync backup number with version number',
-            3: 'Rename omgwtfnzb variables',
-            4: 'Add newznab catIDs',
-            5: 'Metadata update',
-            6: 'Convert from XBMC to new KODI variables',
-            7: 'Use version 2 for password encryption',
-            8: 'Convert Plex setting keys',
-            9: 'Rename autopostprocesser (typo) to autopostprocessor',
-            10: 'Refactor flatten_folders_default to season_folders_default',
-            11: 'Remove old Kodi notifier, and move Kodi 12+ settings under the correct variables',
-            12: 'Convert new_qbittorrent and rtorrent9 setting to qbittorent and rtorrent'
+            1: "Custom naming",
+            2: "Sync backup number with version number",
+            3: "Rename omgwtfnzb variables",
+            4: "Add newznab catIDs",
+            5: "Metadata update",
+            6: "Convert from XBMC to new KODI variables",
+            7: "Use version 2 for password encryption",
+            8: "Convert Plex setting keys",
+            9: "Rename autopostprocesser (typo) to autopostprocessor",
+            10: "Refactor flatten_folders_default to season_folders_default",
+            11: "Remove old Kodi notifier, and move Kodi 12+ settings under the correct variables",
+            12: "Convert new_qbittorrent and rtorrent9 setting to qbittorent and rtorrent",
         }
 
     def migrate_config(self):
@@ -915,9 +933,9 @@ class ConfigMigrator(object):
             next_version = self.config_version + 1
 
             if next_version in self.migration_names:
-                migration_name = ': ' + self.migration_names[next_version]
+                migration_name = ": " + self.migration_names[next_version]
             else:
-                migration_name = ''
+                migration_name = ""
 
             logger.info("Backing up config before upgrade")
             if not helpers.backupVersionedFile(settings.CONFIG_FILE, self.config_version):
@@ -927,7 +945,7 @@ class ConfigMigrator(object):
 
             # do the migration, expect a method named _migrate_v<num>
             logger.info("Migrating config up to version " + str(next_version) + migration_name)
-            getattr(self, '_migrate_v' + str(next_version))()
+            getattr(self, "_migrate_v" + str(next_version))()
             self.config_version = next_version
 
             # save new config after migration
@@ -944,7 +962,7 @@ class ConfigMigrator(object):
         settings.NAMING_PATTERN = self._name_to_pattern()
         logger.info("Based on your old settings I'm setting your new naming pattern to: " + settings.NAMING_PATTERN)
 
-        settings.NAMING_CUSTOM_ABD = check_setting_bool(self.config_obj, 'General', 'naming_dates')
+        settings.NAMING_CUSTOM_ABD = check_setting_bool(self.config_obj, "General", "naming_dates")
 
         if settings.NAMING_CUSTOM_ABD:
             settings.NAMING_ABD_PATTERN = self._name_to_pattern(True)
@@ -952,7 +970,7 @@ class ConfigMigrator(object):
         else:
             settings.NAMING_ABD_PATTERN = naming.name_abd_presets[0]
 
-        settings.NAMING_MULTI_EP = int(check_setting_int(self.config_obj, 'General', 'naming_multi_ep_type', 1))
+        settings.NAMING_MULTI_EP = int(check_setting_int(self.config_obj, "General", "naming_multi_ep_type", 1))
 
         # see if any of their shows used season folders
         main_db_con = db.DBConnection()
@@ -961,16 +979,15 @@ class ConfigMigrator(object):
         # if any shows had season folders on then prepend season folder to the pattern
         if season_folder_shows:
 
-            old_season_format = check_setting_str(self.config_obj, 'General', 'season_folders_format', 'Season %02d')
+            old_season_format = check_setting_str(self.config_obj, "General", "season_folders_format", "Season %02d")
 
             if old_season_format:
                 try:
                     new_season_format = old_season_format % 9
-                    new_season_format = str(new_season_format).replace('09', '%0S')
-                    new_season_format = new_season_format.replace('9', '%S')
+                    new_season_format = str(new_season_format).replace("09", "%0S")
+                    new_season_format = new_season_format.replace("9", "%S")
 
-                    logger.info(
-                        "Changed season folder format from " + old_season_format + " to " + new_season_format + ", prepending it to your naming config")
+                    logger.info("Changed season folder format from " + old_season_format + " to " + new_season_format + ", prepending it to your naming config")
                     settings.NAMING_PATTERN = new_season_format + os.sep + settings.NAMING_PATTERN
 
                 except (TypeError, ValueError):
@@ -989,33 +1006,28 @@ class ConfigMigrator(object):
     def _name_to_pattern(self, abd=False):
 
         # get the old settings from the file
-        use_periods = check_setting_bool(self.config_obj, 'General', 'naming_use_periods')
-        ep_type = check_setting_int(self.config_obj, 'General', 'naming_ep_type')
-        sep_type = check_setting_int(self.config_obj, 'General', 'naming_sep_type')
-        use_quality = check_setting_bool(self.config_obj, 'General', 'naming_quality')
+        use_periods = check_setting_bool(self.config_obj, "General", "naming_use_periods")
+        ep_type = check_setting_int(self.config_obj, "General", "naming_ep_type")
+        sep_type = check_setting_int(self.config_obj, "General", "naming_sep_type")
+        use_quality = check_setting_bool(self.config_obj, "General", "naming_quality")
 
-        use_show_name = check_setting_bool(self.config_obj, 'General', 'naming_show_name', True)
-        use_ep_name = check_setting_bool(self.config_obj, 'General', 'naming_ep_name', True)
+        use_show_name = check_setting_bool(self.config_obj, "General", "naming_show_name", True)
+        use_ep_name = check_setting_bool(self.config_obj, "General", "naming_ep_name", True)
 
         # make the presets into templates
-        _naming_ep_type = (
-            "%Sx%0E",
-            "s%0Se%0E",
-            "S%0SE%0E",
-            "%0Sx%0E"
-        )
+        _naming_ep_type = ("%Sx%0E", "s%0Se%0E", "S%0SE%0E", "%0Sx%0E")
 
         # set up our data to use
         if use_periods:
-            show_name = '%S.N'
-            ep_name = '%E.N'
-            ep_quality = '%Q.N'
-            abd_string = '%A.D'
+            show_name = "%S.N"
+            ep_name = "%E.N"
+            ep_quality = "%Q.N"
+            abd_string = "%A.D"
         else:
-            show_name = '%SN'
-            ep_name = '%EN'
-            ep_quality = '%QN'
-            abd_string = '%A-D'
+            show_name = "%SN"
+            ep_name = "%EN"
+            ep_quality = "%QN"
+            abd_string = "%A-D"
 
         if abd and abd_string:
             ep_string = abd_string
@@ -1055,15 +1067,15 @@ class ConfigMigrator(object):
         Reads in the old naming settings from your config and generates a new config template from them.
         """
         # get the old settings from the file and store them in the new variable names
-        settings.OMGWTFNZBS_USERNAME = check_setting_str(self.config_obj, 'omgwtfnzbs', 'omgwtfnzbs_uid')
-        settings.OMGWTFNZBS_APIKEY = check_setting_str(self.config_obj, 'omgwtfnzbs', 'omgwtfnzbs_key')
+        settings.OMGWTFNZBS_USERNAME = check_setting_str(self.config_obj, "omgwtfnzbs", "omgwtfnzbs_uid")
+        settings.OMGWTFNZBS_APIKEY = check_setting_str(self.config_obj, "omgwtfnzbs", "omgwtfnzbs_key")
 
     # Migration v4: Add default newznab catIDs
     def _migrate_v4(self):
         """ Update newznab providers so that the category IDs can be set independently via the config """
 
         new_newznab_data = []
-        old_newznab_data = check_setting_str(self.config_obj, 'Newznab', 'newznab_data')
+        old_newznab_data = check_setting_str(self.config_obj, "Newznab", "newznab_data")
 
         if old_newznab_data:
             old_newznab_data_list = old_newznab_data.split("!!!")
@@ -1075,13 +1087,13 @@ class ConfigMigrator(object):
                     logger.error("Skipping Newznab provider string: '" + cur_provider_data + "', incorrect format")
                     continue
 
-                if name == 'Sick Beard Index':
-                    key = '0'
+                if name == "Sick Beard Index":
+                    key = "0"
 
-                if name == 'NZBs.org':
-                    catIDs = '5030,5040,5060,5070,5090'
+                if name == "NZBs.org":
+                    catIDs = "5030,5040,5060,5070,5090"
                 else:
-                    catIDs = '5030,5040,5060'
+                    catIDs = "5030,5040,5060"
 
                 cur_provider_data_list = [name, url, key, catIDs, enabled]
                 new_newznab_data.append("|".join(cur_provider_data_list))
@@ -1115,69 +1127,69 @@ class ConfigMigrator(object):
         Migrate the poster override to just using the banner option (applies to xbmc only).
         """
 
-        metadata_xbmc = check_setting_str(self.config_obj, 'General', 'metadata_xbmc', '0|0|0|0|0|0')
-        metadata_xbmc_12plus = check_setting_str(self.config_obj, 'General', 'metadata_xbmc_12plus', '0|0|0|0|0|0')
-        metadata_mediabrowser = check_setting_str(self.config_obj, 'General', 'metadata_mediabrowser', '0|0|0|0|0|0')
-        metadata_ps3 = check_setting_str(self.config_obj, 'General', 'metadata_ps3', '0|0|0|0|0|0')
-        metadata_wdtv = check_setting_str(self.config_obj, 'General', 'metadata_wdtv', '0|0|0|0|0|0')
-        metadata_tivo = check_setting_str(self.config_obj, 'General', 'metadata_tivo', '0|0|0|0|0|0')
-        metadata_mede8er = check_setting_str(self.config_obj, 'General', 'metadata_mede8er', '0|0|0|0|0|0')
+        metadata_xbmc = check_setting_str(self.config_obj, "General", "metadata_xbmc", "0|0|0|0|0|0")
+        metadata_xbmc_12plus = check_setting_str(self.config_obj, "General", "metadata_xbmc_12plus", "0|0|0|0|0|0")
+        metadata_mediabrowser = check_setting_str(self.config_obj, "General", "metadata_mediabrowser", "0|0|0|0|0|0")
+        metadata_ps3 = check_setting_str(self.config_obj, "General", "metadata_ps3", "0|0|0|0|0|0")
+        metadata_wdtv = check_setting_str(self.config_obj, "General", "metadata_wdtv", "0|0|0|0|0|0")
+        metadata_tivo = check_setting_str(self.config_obj, "General", "metadata_tivo", "0|0|0|0|0|0")
+        metadata_mede8er = check_setting_str(self.config_obj, "General", "metadata_mede8er", "0|0|0|0|0|0")
 
-        use_banner = check_setting_bool(self.config_obj, 'General', 'use_banner')
+        use_banner = check_setting_bool(self.config_obj, "General", "use_banner")
 
         def _migrate_metadata(metadata, metadata_name, _use_banner):
-            cur_metadata = metadata.split('|')
+            cur_metadata = metadata.split("|")
             # if target has the old number of values, do upgrade
             if len(cur_metadata) == 6:
                 logger.info("Upgrading " + metadata_name + " metadata, old value: " + metadata)
-                cur_metadata.insert(4, '0')
-                cur_metadata.append('0')
-                cur_metadata.append('0')
-                cur_metadata.append('0')
+                cur_metadata.insert(4, "0")
+                cur_metadata.append("0")
+                cur_metadata.append("0")
+                cur_metadata.append("0")
                 # swap show fanart, show poster
                 cur_metadata[3], cur_metadata[2] = cur_metadata[2], cur_metadata[3]
                 # if user was using _use_banner to override the poster, instead enable the banner option and deactivate poster
-                if metadata_name == 'XBMC' and _use_banner:
-                    cur_metadata[4], cur_metadata[3] = cur_metadata[3], '0'
+                if metadata_name == "XBMC" and _use_banner:
+                    cur_metadata[4], cur_metadata[3] = cur_metadata[3], "0"
                 # write new format
-                metadata = '|'.join(cur_metadata)
+                metadata = "|".join(cur_metadata)
                 logger.info("Upgrading " + metadata_name + " metadata, new value: " + metadata)
 
             elif len(cur_metadata) == 10:
 
-                metadata = '|'.join(cur_metadata)
+                metadata = "|".join(cur_metadata)
                 logger.info("Keeping " + metadata_name + " metadata, value: " + metadata)
 
             else:
                 logger.error("Skipping " + metadata_name + " metadata: '" + metadata + "', incorrect format")
-                metadata = '0|0|0|0|0|0|0|0|0|0'
+                metadata = "0|0|0|0|0|0|0|0|0|0"
                 logger.info("Setting " + metadata_name + " metadata, new value: " + metadata)
 
             return metadata
 
-        settings.METADATA_XBMC = _migrate_metadata(metadata_xbmc, 'XBMC', use_banner)
-        settings.METADATA_XBMC_12PLUS = _migrate_metadata(metadata_xbmc_12plus, 'XBMC 12+', use_banner)
-        settings.METADATA_MEDIABROWSER = _migrate_metadata(metadata_mediabrowser, 'MediaBrowser', use_banner)
-        settings.METADATA_PS3 = _migrate_metadata(metadata_ps3, 'PS3', use_banner)
-        settings.METADATA_WDTV = _migrate_metadata(metadata_wdtv, 'WDTV', use_banner)
-        settings.METADATA_TIVO = _migrate_metadata(metadata_tivo, 'TIVO', use_banner)
-        settings.METADATA_MEDE8ER = _migrate_metadata(metadata_mede8er, 'Mede8er', use_banner)
+        settings.METADATA_XBMC = _migrate_metadata(metadata_xbmc, "XBMC", use_banner)
+        settings.METADATA_XBMC_12PLUS = _migrate_metadata(metadata_xbmc_12plus, "XBMC 12+", use_banner)
+        settings.METADATA_MEDIABROWSER = _migrate_metadata(metadata_mediabrowser, "MediaBrowser", use_banner)
+        settings.METADATA_PS3 = _migrate_metadata(metadata_ps3, "PS3", use_banner)
+        settings.METADATA_WDTV = _migrate_metadata(metadata_wdtv, "WDTV", use_banner)
+        settings.METADATA_TIVO = _migrate_metadata(metadata_tivo, "TIVO", use_banner)
+        settings.METADATA_MEDE8ER = _migrate_metadata(metadata_mede8er, "Mede8er", use_banner)
 
     # Migration v6: Convert from XBMC to KODI variables
     def _migrate_v6(self):
-        settings.USE_KODI = check_setting_bool(self.config_obj, 'XBMC', 'use_xbmc')
-        settings.KODI_ALWAYS_ON = check_setting_bool(self.config_obj, 'XBMC', 'xbmc_always_on', True)
-        settings.KODI_NOTIFY_ONSNATCH = check_setting_bool(self.config_obj, 'XBMC', 'xbmc_notify_onsnatch')
-        settings.KODI_NOTIFY_ONDOWNLOAD = check_setting_bool(self.config_obj, 'XBMC', 'xbmc_notify_ondownload')
-        settings.KODI_NOTIFY_ONSUBTITLEDOWNLOAD = check_setting_bool(self.config_obj, 'XBMC', 'xbmc_notify_onsubtitledownload')
-        settings.KODI_UPDATE_LIBRARY = check_setting_bool(self.config_obj, 'XBMC', 'xbmc_update_library')
-        settings.KODI_UPDATE_FULL = check_setting_bool(self.config_obj, 'XBMC', 'xbmc_update_full')
-        settings.KODI_UPDATE_ONLYFIRST = check_setting_bool(self.config_obj, 'XBMC', 'xbmc_update_onlyfirst')
-        settings.KODI_HOST = check_setting_str(self.config_obj, 'XBMC', 'xbmc_host')
-        settings.KODI_USERNAME = check_setting_str(self.config_obj, 'XBMC', 'xbmc_username', censor_log=True)
-        settings.KODI_PASSWORD = check_setting_str(self.config_obj, 'XBMC', 'xbmc_password', censor_log=True)
-        settings.METADATA_KODI = check_setting_str(self.config_obj, 'General', 'metadata_xbmc', '0|0|0|0|0|0|0|0|0|0')
-        settings.METADATA_KODI_12PLUS = check_setting_str(self.config_obj, 'General', 'metadata_xbmc_12plus', '0|0|0|0|0|0|0|0|0|0')
+        settings.USE_KODI = check_setting_bool(self.config_obj, "XBMC", "use_xbmc")
+        settings.KODI_ALWAYS_ON = check_setting_bool(self.config_obj, "XBMC", "xbmc_always_on", True)
+        settings.KODI_NOTIFY_ONSNATCH = check_setting_bool(self.config_obj, "XBMC", "xbmc_notify_onsnatch")
+        settings.KODI_NOTIFY_ONDOWNLOAD = check_setting_bool(self.config_obj, "XBMC", "xbmc_notify_ondownload")
+        settings.KODI_NOTIFY_ONSUBTITLEDOWNLOAD = check_setting_bool(self.config_obj, "XBMC", "xbmc_notify_onsubtitledownload")
+        settings.KODI_UPDATE_LIBRARY = check_setting_bool(self.config_obj, "XBMC", "xbmc_update_library")
+        settings.KODI_UPDATE_FULL = check_setting_bool(self.config_obj, "XBMC", "xbmc_update_full")
+        settings.KODI_UPDATE_ONLYFIRST = check_setting_bool(self.config_obj, "XBMC", "xbmc_update_onlyfirst")
+        settings.KODI_HOST = check_setting_str(self.config_obj, "XBMC", "xbmc_host")
+        settings.KODI_USERNAME = check_setting_str(self.config_obj, "XBMC", "xbmc_username", censor_log=True)
+        settings.KODI_PASSWORD = check_setting_str(self.config_obj, "XBMC", "xbmc_password", censor_log=True)
+        settings.METADATA_KODI = check_setting_str(self.config_obj, "General", "metadata_xbmc", "0|0|0|0|0|0|0|0|0|0")
+        settings.METADATA_KODI_12PLUS = check_setting_str(self.config_obj, "General", "metadata_xbmc_12plus", "0|0|0|0|0|0|0|0|0|0")
 
     # Migration v7: Use version 2 for password encryption
     @staticmethod
@@ -1186,23 +1198,23 @@ class ConfigMigrator(object):
 
     # Migration v8: Rename plex settings
     def _migrate_v8(self):
-        settings.PLEX_CLIENT_HOST = check_setting_str(self.config_obj, 'Plex', 'plex_host')
-        settings.PLEX_SERVER_USERNAME = check_setting_str(self.config_obj, 'Plex', 'plex_username', censor_log=True)
-        settings.PLEX_SERVER_PASSWORD = check_setting_str(self.config_obj, 'Plex', 'plex_password', censor_log=True)
-        settings.USE_PLEX_SERVER = check_setting_bool(self.config_obj, 'Plex', 'use_plex')
+        settings.PLEX_CLIENT_HOST = check_setting_str(self.config_obj, "Plex", "plex_host")
+        settings.PLEX_SERVER_USERNAME = check_setting_str(self.config_obj, "Plex", "plex_username", censor_log=True)
+        settings.PLEX_SERVER_PASSWORD = check_setting_str(self.config_obj, "Plex", "plex_password", censor_log=True)
+        settings.USE_PLEX_SERVER = check_setting_bool(self.config_obj, "Plex", "use_plex")
 
     # Migration v9: Rename autopostprocesser (typo) to autopostprocessor
     def _migrate_v9(self):
-        settings.AUTOPOSTPROCESSOR_FREQUENCY = check_setting_str(self.config_obj, 'General', 'autopostprocesser_frequency')
+        settings.AUTOPOSTPROCESSOR_FREQUENCY = check_setting_str(self.config_obj, "General", "autopostprocesser_frequency")
 
     # Migration v10: Change flatten_folders_default to season_folders_default (inverted)
     def _migrate_v10(self):
-        settings.SEASON_FOLDERS_DEFAULT = not check_setting_str(self.config_obj, 'General', 'flatten_folders_default')
+        settings.SEASON_FOLDERS_DEFAULT = not check_setting_str(self.config_obj, "General", "flatten_folders_default")
 
     # Migration v11: Remove old kodi and only use Kodi 12+
     def _migrate_v11(self):
-        settings.METADATA_KODI = check_setting_str(settings.CFG, 'General', 'metadata_kodi_12plus', '0|0|0|0|0|0|0|0|0|0')
+        settings.METADATA_KODI = check_setting_str(settings.CFG, "General", "metadata_kodi_12plus", "0|0|0|0|0|0|0|0|0|0")
 
     # Migration v12: Fix selected provider, since there is only one qbittorrent and one rtorrent provider
     def _migrate_v12(self):
-        settings.TORRENT_METHOD = re.sub(r'^new_|9$', '', check_setting_str(settings.CFG, 'General', 'torrent_method', 'blackhole'))
+        settings.TORRENT_METHOD = re.sub(r"^new_|9$", "", check_setting_str(settings.CFG, "General", "torrent_method", "blackhole"))
