@@ -13,18 +13,15 @@ class Provider(NZBProvider):
 
         self.cache = OmgwtfnzbsCache(self)
 
-        self.url = 'https://omgwtfnzbs.me/'
-        self.urls = {
-            'rss': 'https://rss.omgwtfnzbs.me/rss-download.php',
-            'api': 'https://api.omgwtfnzbs.me/json/'
-        }
+        self.url = "https://omgwtfnzbs.me/"
+        self.urls = {"rss": "https://rss.omgwtfnzbs.me/rss-download.php", "api": "https://api.omgwtfnzbs.me/json/"}
 
-        self.proper_strings = ['.PROPER.', '.REPACK.']
+        self.proper_strings = [".PROPER.", ".REPACK."]
 
     def _check_auth(self):
 
         if not self.username or not self.api_key:
-            logger.warning('Invalid api key. Check your settings')
+            logger.warning("Invalid api key. Check your settings")
             return False
 
         return True
@@ -38,21 +35,21 @@ class Provider(NZBProvider):
             # provider doesn't return xml on error
             return True
 
-        if 'notice' in parsed_data:
-            description_text = parsed_data.get('notice')
-            if 'information is incorrect' in description_text:
-                logger.warning('Invalid api key. Check your settings')
-            elif '0 results matched your terms' not in description_text:
-                logger.debug('Unknown error: {0}'.format(description_text))
+        if "notice" in parsed_data:
+            description_text = parsed_data.get("notice")
+            if "information is incorrect" in description_text:
+                logger.warning("Invalid api key. Check your settings")
+            elif "0 results matched your terms" not in description_text:
+                logger.debug("Unknown error: {0}".format(description_text))
             return False
 
         return True
 
     def _get_title_and_url(self, item):
-        return item['release'], item['getnzb']
+        return item["release"], item["getnzb"]
 
     def _get_size(self, item):
-        return try_int(item['sizebytes'], -1)
+        return try_int(item["sizebytes"], -1)
 
     def search(self, search_strings, age=0, ep_obj=None):
         results = []
@@ -60,24 +57,24 @@ class Provider(NZBProvider):
             return results
 
         search_params = {
-            'user': self.username,
-            'api': self.api_key,
-            'eng': 1,
-            'catid': '19,20,30',  # SD,HD,UHD
-            'retention': settings.USENET_RETENTION,
+            "user": self.username,
+            "api": self.api_key,
+            "eng": 1,
+            "catid": "19,20,30",  # SD,HD,UHD
+            "retention": settings.USENET_RETENTION,
         }
 
         for mode in search_strings:
             items = []
             logger.debug(_("Search Mode: {mode}".format(mode=mode)))
-            for search_string in search_strings[mode]:
-                search_params['search'] = search_string
-                if mode != 'RSS':
+            for search_string in {*search_strings[mode]}:
+                search_params["search"] = search_string
+                if mode != "RSS":
                     logger.debug(_("Search String: {search_string}".format(search_string=search_string)))
 
-                data = self.get_url(self.urls['api'], params=search_params, returns='json')
+                data = self.get_url(self.urls["api"], params=search_params, returns="json")
                 if not data:
-                    logger.debug(_('No data returned from provider'))
+                    logger.debug(_("No data returned from provider"))
                     continue
 
                 if not self._check_auth_from_data(data, is_XML=False):
@@ -87,7 +84,7 @@ class Provider(NZBProvider):
                     if not self._get_title_and_url(item):
                         continue
 
-                    logger.debug(_('Found result: ') + f'{item.get("release")}')
+                    logger.debug(_("Found result: ") + f'{item.get("release")}')
                     items.append(item)
 
             results += items
@@ -97,21 +94,21 @@ class Provider(NZBProvider):
 
 class OmgwtfnzbsCache(tvcache.TVCache):
     def _get_title_and_url(self, item):
-        title = item.get('title')
+        title = item.get("title")
         if title:
-            title = title.replace(' ', '.')
+            title = title.replace(" ", ".")
 
-        url = item.get('link')
+        url = item.get("link")
         if url:
-            url = url.replace('&amp;', '&')
+            url = url.replace("&amp;", "&")
 
         return title, url
 
     def _get_rss_data(self):
         search_params = {
-            'user': self.provider.username,
-            'api': self.provider.api_key,
-            'eng': 1,
-            'catid': '19,20,30',  # SD,HD,UHD
+            "user": self.provider.username,
+            "api": self.provider.api_key,
+            "eng": 1,
+            "catid": "19,20,30",  # SD,HD,UHD
         }
-        return self.get_rss_feed(self.provider.urls['rss'], params=search_params)
+        return self.get_rss_feed(self.provider.urls["rss"], params=search_params)
