@@ -11,7 +11,6 @@ from sickchill.providers.torrent.TorrentProvider import TorrentProvider
 
 
 class Provider(TorrentProvider):
-
     def __init__(self):
 
         # Provider Init
@@ -28,17 +27,13 @@ class Provider(TorrentProvider):
 
         # URLs
         self.custom_url = None
-        self.url = 'https://www.torrentday.com'
-        self.urls = {
-            'login': urljoin(self.url, '/t'),
-            'search': urljoin(self.url, '/t.json'),
-            'download': urljoin(self.url, '/download.php/')
-        }
+        self.url = "https://www.torrentday.com"
+        self.urls = {"login": urljoin(self.url, "/t"), "search": urljoin(self.url, "/t.json"), "download": urljoin(self.url, "/download.php/")}
 
         self.categories = {
-            'Season': {'14': 1},
-            'Episode': {'2': 1, '26': 1, '7': 1, '24': 1, '34': 1},
-            'RSS': {'2': 1, '26': 1, '7': 1, '24': 1, '34': 1, '14': 1}
+            "Season": {"14": 1},
+            "Episode": {"2": 1, "26": 1, "7": 1, "24": 1, "34": 1},
+            "RSS": {"2": 1, "26": 1, "7": 1, "24": 1, "34": 1, "14": 1},
         }
 
         self.enable_cookies = True
@@ -48,7 +43,7 @@ class Provider(TorrentProvider):
 
     def login(self):
         cookie_dict = dict_from_cookiejar(self.session.cookies)
-        if cookie_dict.get('uid') and cookie_dict.get('pass'):
+        if cookie_dict.get("uid") and cookie_dict.get("pass"):
             return True
 
         if self.cookies:
@@ -57,38 +52,38 @@ class Provider(TorrentProvider):
                 logger.info(status)
                 return False
 
-            login_params = {'username': self.username, 'password': self.password, 'submit.x': 0, 'submit.y': 0}
-            login_url = self.urls['login']
+            login_params = {"username": self.username, "password": self.password, "submit.x": 0, "submit.y": 0}
+            login_url = self.urls["login"]
             if self.custom_url:
                 if not validators.url(self.custom_url):
                     logger.warning("Invalid custom url: {0}".format(self.custom_url))
                     return False
 
-                login_url = urljoin(self.custom_url, self.urls['login'].split(self.url)[1])
+                login_url = urljoin(self.custom_url, self.urls["login"].split(self.url)[1])
 
-            response = self.get_url(login_url, post_data=login_params, returns='response')
+            response = self.get_url(login_url, post_data=login_params, returns="response")
             if not response or response.status_code != 200:
-                logger.warning('Unable to connect to provider')
+                logger.warning("Unable to connect to provider")
                 return False
 
-            if re.search('You tried too often', response.text):
-                logger.warning('Too many login access attempts')
+            if re.search("You tried too often", response.text):
+                logger.warning("Too many login access attempts")
                 return False
 
-            if dict_from_cookiejar(self.session.cookies).get('uid') in response.text:
+            if dict_from_cookiejar(self.session.cookies).get("uid") in response.text:
                 return True
             else:
-                logger.warning('Failed to login, check your cookies')
+                logger.warning("Failed to login, check your cookies")
                 return False
         else:
-            logger.info('You need to set your cookies to use torrentday')
+            logger.info("You need to set your cookies to use torrentday")
             return False
 
     def search(self, search_params, age=0, ep_obj=None):
         results = []
 
-        search_url = self.urls['search']
-        download_url = self.urls['download']
+        search_url = self.urls["search"]
+        download_url = self.urls["download"]
         if self.custom_url:
             if not validators.url(self.custom_url):
                 logger.warning("Invalid custom url: {0}".format(self.custom_url))
@@ -105,7 +100,7 @@ class Provider(TorrentProvider):
             logger.debug(_("Search Mode: {mode}".format(mode=mode)))
             for search_string in search_params[mode]:
 
-                if mode != 'RSS':
+                if mode != "RSS":
                     logger.debug(_("Search String: {search_string}".format(search_string=search_string)))
 
                 get_params = {}
@@ -113,44 +108,47 @@ class Provider(TorrentProvider):
                 get_params["q"] = search_string
 
                 try:
-                    torrents = self.get_url(search_url, params=get_params, returns='json')
+                    torrents = self.get_url(search_url, params=get_params, returns="json")
                     # Handle empty string response or None #4304
                     assert torrents
                     # Make sure it is iterable #4304
                     iter(torrents)
                 except (TypeError, AssertionError):
-                    logger.debug('Data returned from provider does not contain any torrents')
+                    logger.debug("Data returned from provider does not contain any torrents")
                     continue
 
                 for torrent in torrents:
 
-                    title = re.sub(r'\[.*=.*\].*\[/.*\]', '', torrent['name']) if torrent['name'] else None
-                    torrent_url = urljoin(download_url, '{0}/{1}.torrent'.format(torrent['t'], torrent['name'])) if torrent['t'] and torrent['name'] else \
-                        None
+                    title = re.sub(r"\[.*=.*\].*\[/.*\]", "", torrent["name"]) if torrent["name"] else None
+                    torrent_url = urljoin(download_url, "{0}/{1}.torrent".format(torrent["t"], torrent["name"])) if torrent["t"] and torrent["name"] else None
                     if not all([title, torrent_url]):
                         continue
 
-                    seeders = try_int(torrent['seeders'])
-                    leechers = try_int(torrent['leechers'])
+                    seeders = try_int(torrent["seeders"])
+                    leechers = try_int(torrent["leechers"])
 
                     # Filter unseeded torrent
                     if seeders < self.minseed or leechers < self.minleech:
-                        if mode != 'RSS':
-                            logger.debug('Discarding torrent because it doesn\'t meet the minimum seeders or leechers: {0} (S:{1} L:{2})'.format(title, seeders, leechers))
+                        if mode != "RSS":
+                            logger.debug(
+                                "Discarding torrent because it doesn't meet the minimum seeders or leechers: {0} (S:{1} L:{2})".format(title, seeders, leechers)
+                            )
                         continue
 
-                    torrent_size = torrent['size']
+                    torrent_size = torrent["size"]
                     size = convert_size(torrent_size) or -1
 
-                    item = {'title': title, 'link': torrent_url, 'size': size, 'seeders': seeders, 'leechers': leechers, 'hash': ''}
+                    item = {"title": title, "link": torrent_url, "size": size, "seeders": seeders, "leechers": leechers, "hash": ""}
 
-                    if mode != 'RSS':
-                        logger.debug(_('Found result: {title} with {seeders} seeders and {leechers} leechers'.format(title=title, seeders=seeders, leechers=leechers)))
+                    if mode != "RSS":
+                        logger.debug(
+                            _("Found result: {title} with {seeders} seeders and {leechers} leechers".format(title=title, seeders=seeders, leechers=leechers))
+                        )
 
                     items.append(item)
 
             # For each search mode sort all the items by seeders if available
-            items.sort(key=lambda d: try_int(d.get('seeders', 0)), reverse=True)
+            items.sort(key=lambda d: try_int(d.get("seeders", 0)), reverse=True)
             results += items
 
         return results
