@@ -3,20 +3,22 @@ import os
 import re
 import threading
 import traceback
+from typing import TYPE_CHECKING
 
 import sickchill.oldbeard.name_cache
 import sickchill.oldbeard.providers
 from sickchill import logger, settings
-from sickchill.helper.common import try_int
 from sickchill.helper.exceptions import AuthException
 from sickchill.providers.GenericProvider import GenericProvider
 
+if TYPE_CHECKING:  # pragma: no cover
+    from sickchill.oldbeard.classes import TorrentSearchResult
+
 from . import clients, common, db, failed_history, helpers, history, notifiers, nzbget, nzbSplitter, sab, show_name_helpers, ui
 from .common import MULTI_EP_RESULT, Quality, SEASON_RESULT, SNATCHED, SNATCHED_BEST, SNATCHED_PROPER
-from .name_parser.parser import InvalidNameException, InvalidShowException, NameParser
 
 
-def _downloadResult(result):
+def _downloadResult(result: "TorrentSearchResult"):
     """
     Downloads a result to the appropriate black hole folder.
 
@@ -36,18 +38,18 @@ def _downloadResult(result):
     elif result.resultType == GenericProvider.NZBDATA:
 
         # get the final file path to the nzb
-        file_name = os.path.join(settings.NZB_DIR, result.name + ".nzb")
+        filename = os.path.join(settings.NZB_DIR, result.name + ".nzb")
 
-        logger.info("Saving NZB to " + file_name)
+        logger.info("Saving NZB to " + filename)
 
         newResult = True
 
         # save the data to disk
         try:
-            with open(file_name, 'w') as fileOut:
+            with open(filename, "w") as fileOut:
                 fileOut.write(result.extraInfo[0])
 
-            helpers.chmodAsParent(file_name)
+            helpers.chmodAsParent(filename)
 
         except EnvironmentError as e:
             logger.exception("Error trying to save NZB to black hole: " + str(e))
@@ -59,7 +61,7 @@ def _downloadResult(result):
     return newResult
 
 
-def snatchEpisode(result, endStatus=SNATCHED):
+def snatchEpisode(result: "TorrentSearchResult", endStatus=SNATCHED):
     """
     Contains the internal logic necessary to actually "snatch" a result that
     has been found.
@@ -72,19 +74,18 @@ def snatchEpisode(result, endStatus=SNATCHED):
     if result is None:
         return False
 
-    result.priority = 0  # -1 = low, 0 = normal, 1 = high
     if settings.ALLOW_HIGH_PRIORITY:
         # if it aired recently make it high priority
         for curEp in result.episodes:
             if datetime.date.today() - curEp.airdate <= datetime.timedelta(days=7):
                 result.priority = 1
 
-    endStatus = SNATCHED_PROPER if re.search(r'\b(proper|repack|real)\b', result.name, re.I) else endStatus
+    endStatus = SNATCHED_PROPER if re.search(r"\b(proper|repack|real)\b", result.name, re.I) else endStatus
 
     # This is breaking if newznab protocol, expecting a torrent from a url and getting a magnet instead.
-    if result.url and 'jackett_apikey' in result.url:
-        response = result.provider.get_url(result.url, allow_redirects=False, returns='response')
-        if response.next and response.next.url and response.next.url.startswith('magnet'):
+    if result.url and "jackett_apikey" in result.url:
+        response = result.provider.get_url(result.url, allow_redirects=False, returns="response")
+        if response.next and response.next.url and response.next.url.startswith("magnet"):
             result.url = response.next.url
 
     # NZBs can be sent straight to SAB or saved to disk
@@ -97,8 +98,7 @@ def snatchEpisode(result, endStatus=SNATCHED):
             is_proper = True if endStatus == SNATCHED_PROPER else False
             dlResult = nzbget.sendNZB(result, is_proper)
         elif settings.NZB_METHOD == "download_station":
-            client = clients.getClientInstance(settings.NZB_METHOD)(
-                settings.SYNOLOGY_DSM_HOST, settings.SYNOLOGY_DSM_USERNAME, settings.SYNOLOGY_DSM_PASSWORD)
+            client = clients.getClientInstance(settings.NZB_METHOD)(settings.SYNOLOGY_DSM_HOST, settings.SYNOLOGY_DSM_USERNAME, settings.SYNOLOGY_DSM_PASSWORD)
             dlResult = client.sendNZB(result)
         else:
             logger.exception("Unknown NZB action specified in config: " + settings.NZB_METHOD)
@@ -110,11 +110,11 @@ def snatchEpisode(result, endStatus=SNATCHED):
         if settings.TORRENT_METHOD == "blackhole":
             dlResult = _downloadResult(result)
         else:
-            if not result.content and not result.url.startswith('magnet'):
+            if not result.content and not result.url.startswith("magnet"):
                 if result.provider.login():
-                    result.content = result.provider.get_url(result.url, returns='content')
+                    result.content = result.provider.get_url(result.url, returns="content")
 
-            if result.content or result.url.startswith('magnet'):
+            if result.content or result.url.startswith("magnet"):
                 client = clients.getClientInstance(settings.TORRENT_METHOD)()
                 dlResult = client.sendTORRENT(result)
             else:
@@ -130,7 +130,7 @@ def snatchEpisode(result, endStatus=SNATCHED):
     if settings.USE_FAILED_DOWNLOADS:
         failed_history.logSnatch(result)
 
-    ui.notifications.message('Episode snatched', result.name)
+    ui.notifications.message("Episode snatched", result.name)
 
     history.logSnatch(result)
 
@@ -148,7 +148,7 @@ def snatchEpisode(result, endStatus=SNATCHED):
 
         if curEpObj.status not in Quality.DOWNLOADED:
             try:
-                notifiers.notify_snatch("{0} from {1}".format(curEpObj._format_pattern('%SN - %Sx%0E - %EN - %QN'), result.provider.name))
+                notifiers.notify_snatch("{0} from {1}".format(curEpObj._format_pattern("%SN - %Sx%0E - %EN - %QN"), result.provider.name))
             except Exception:
                 # Without this, when notification fail, it crashes the snatch thread and SR will
                 # keep snatching until notification is sent
@@ -208,9 +208,8 @@ def pickBestResult(results, show):
         if not show_name_helpers.filter_bad_releases(cur_result.name, parse=False, show=show):
             continue
 
-        if hasattr(cur_result, 'size'):
-            if settings.USE_FAILED_DOWNLOADS and failed_history.hasFailed(cur_result.name, cur_result.size,
-                                                                          cur_result.provider.name):
+        if hasattr(cur_result, "size"):
+            if settings.USE_FAILED_DOWNLOADS and failed_history.hasFailed(cur_result.name, cur_result.size, cur_result.provider.name):
                 logger.info(cur_result.name + " has previously failed, rejecting it")
                 continue
 
@@ -239,7 +238,7 @@ def pickBestResult(results, show):
     return bestResult
 
 
-def isFinalResult(result):
+def isFinalResult(result: "TorrentSearchResult"):
     """
     Checks if the given result is good enough quality that we can stop searching for other ones.
 
@@ -273,7 +272,7 @@ def isFinalResult(result):
         return False
 
 
-def isFirstBestMatch(result):
+def isFirstBestMatch(result: "TorrentSearchResult"):
     """
     Checks if the given result is a best quality match and if we want to stop searching providers here.
 
@@ -309,8 +308,7 @@ def wantedEpisodes(show, fromDate):
     con = db.DBConnection()
 
     sql_results = con.select(
-        "SELECT status, season, episode FROM tv_episodes WHERE showid = ? AND season > 0 and airdate > ?",
-        [show.indexerid, fromDate.toordinal()]
+        "SELECT status, season, episode FROM tv_episodes WHERE showid = ? AND season > 0 and airdate > ?", [show.indexerid, fromDate.toordinal()]
     )
 
     # check through the list of statuses to see if we want any
@@ -447,14 +445,17 @@ def searchProviders(show, episodes, manualSearch=False, downCurQuality=False):
         search_mode = curProvider.search_mode
 
         # Always search for episode when manually searching when in sponly
-        if search_mode == 'sponly' and manualSearch is True:
-            search_mode = 'eponly'
+        if search_mode == "sponly" and manualSearch is True:
+            search_mode = "eponly"
 
         while True:
             searchCount += 1
 
-            logger.info(_("Performing {episode_or_season} search for {show}").format(
-                episode_or_season=(_('season pack'), _('episode'))[search_mode == 'eponly'], show=show.name))
+            logger.info(
+                _("Performing {episode_or_season} search for {show}").format(
+                    episode_or_season=(_("season pack"), _("episode"))[search_mode == "eponly"], show=show.name
+                )
+            )
 
             try:
                 searchResults = curProvider.find_search_results(show, episodes, search_mode, manualSearch, downCurQuality)
@@ -477,15 +478,15 @@ def searchProviders(show, episodes, manualSearch=False, downCurQuality=False):
                         foundResults[curProvider.name][curEp] = searchResults[curEp]
 
                 break
-            elif not curProvider.search_fallback or searchCount == 2:
+            elif searchCount == 2 or not curProvider.search_fallback:
                 break
 
-            if search_mode == 'sponly':
+            if search_mode == "sponly":
                 logger.debug("Fallback episode search initiated")
-                search_mode = 'eponly'
+                search_mode = "eponly"
             else:
                 logger.debug("Fallback season pack search initiate")
-                search_mode = 'sponly'
+                search_mode = "sponly"
 
         # skip to next provider if we have no results to process
         if not foundResults[curProvider.name]:
@@ -512,12 +513,16 @@ def searchProviders(show, episodes, manualSearch=False, downCurQuality=False):
             logger.info("The quality of the season " + bestSeasonResult.provider.provider_type + " is " + Quality.qualityStrings[seasonQual])
 
             main_db_con = db.DBConnection()
-            allEps = [int(x["episode"])
-                      for x in main_db_con.select("SELECT episode FROM tv_episodes WHERE showid = ? AND ( season IN ( " + ','.join(searchedSeasons) + " ) )",
-                                                  [show.indexerid])]
+            allEps = [
+                int(x["episode"])
+                for x in main_db_con.select(
+                    "SELECT episode FROM tv_episodes WHERE showid = ? AND ( season IN ( " + ",".join(searchedSeasons) + " ) )", [show.indexerid]
+                )
+            ]
 
             logger.info(
-                "Executed query: [SELECT episode FROM tv_episodes WHERE showid = {0} AND season in  {1}]".format(show.indexerid, ','.join(searchedSeasons)))
+                "Executed query: [SELECT episode FROM tv_episodes WHERE showid = {0} AND season in  {1}]".format(show.indexerid, ",".join(searchedSeasons))
+            )
             logger.debug("Episode list: " + str(allEps))
 
             allWanted = True
@@ -531,8 +536,7 @@ def searchProviders(show, episodes, manualSearch=False, downCurQuality=False):
 
             # if we need every ep in the season and there's nothing better then just download this and be done with it (unless single episodes are preferred)
             if allWanted and bestSeasonResult.quality == highest_quality_overall:
-                logger.info(
-                    "Every ep in this season is needed, downloading the whole " + bestSeasonResult.provider.provider_type + " " + bestSeasonResult.name)
+                logger.info("Every ep in this season is needed, downloading the whole " + bestSeasonResult.provider.provider_type + " " + bestSeasonResult.name)
                 epObjs = []
                 for curEpNum in allEps:
                     for season in {x.season for x in episodes}:
@@ -570,7 +574,8 @@ def searchProviders(show, episodes, manualSearch=False, downCurQuality=False):
 
                     # Season result from Torrent Provider must be a full-season torrent, creating multi-ep result for it.
                     logger.info(
-                        "Adding multi-ep result for full-season torrent. Set the episodes you don't want to 'don't download' in your torrent client if desired!")
+                        "Adding multi-ep result for full-season torrent. Set the episodes you don't want to 'don't download' in your torrent client if desired!"
+                    )
                     epObjs = []
                     for curEpNum in allEps:
                         for season in {x.season for x in episodes}:
@@ -619,13 +624,10 @@ def searchProviders(show, episodes, manualSearch=False, downCurQuality=False):
                     else:
                         multiNeededEps.append(epObj.episode)
 
-                logger.debug(
-                    "Multi-ep check result is multiNeededEps: " + str(multiNeededEps) + ", multiNotNeededEps: " + str(
-                        multiNotNeededEps))
+                logger.debug("Multi-ep check result is multiNeededEps: " + str(multiNeededEps) + ", multiNotNeededEps: " + str(multiNotNeededEps))
 
                 if not multiNeededEps:
-                    logger.debug(
-                        "All of these episodes were covered by another multi-episode nzbs, ignoring this multi-ep result")
+                    logger.debug("All of these episodes were covered by another multi-episode nzbs, ignoring this multi-ep result")
                     continue
 
                 # don't bother with the single result if we're going to get it with a multi result
@@ -633,8 +635,10 @@ def searchProviders(show, episodes, manualSearch=False, downCurQuality=False):
                     multiResults[epObj.episode] = multiResult
                     if epObj.episode in foundResults[curProvider.name]:
                         logger.debug(
-                            "A needed multi-episode result overlaps with a single-episode result for ep #" + str(
-                                epObj.episode) + ", removing the single-episode results from the list")
+                            "A needed multi-episode result overlaps with a single-episode result for ep #"
+                            + str(epObj.episode)
+                            + ", removing the single-episode results from the list"
+                        )
                         del foundResults[curProvider.name][epObj.episode]
 
         # of all the single ep results narrow it down to the best one for each episode
@@ -680,96 +684,3 @@ def searchProviders(show, episodes, manualSearch=False, downCurQuality=False):
     # Remove provider from thread name before return results
     threading.currentThread().name = origThreadName
     return finalResults
-
-
-def searchProvidersList(show, episodes, search_mode='eponly'):
-    """
-    Walk providers for information on shows
-
-    :param show: Show we are looking for
-    :param episodes: Episodes we hope to find
-    :param search_mode: String, eponly|sponly: Episode search or Season Pack Search?
-    :return: results for search
-    """
-    foundResults = {"results": []}
-
-    didSearch = False
-
-    origThreadName = threading.currentThread().name
-
-    # build name cache for show
-    sickchill.oldbeard.name_cache.build_name_cache(show)
-
-    providers = [x for x in sickchill.oldbeard.providers.sortedProviderList(settings.RANDOMIZE_PROVIDERS) if x.is_active and x.can_backlog and x.enable_backlog]
-    if not providers:
-        logger.info("No NZB/Torrent providers found or enabled in the sickchill config for backlog searches. Please check your settings.")
-        return foundResults
-
-    episodes = [episodes]
-    search_episodes = {}
-    for ep in episodes:
-        if ep.season not in search_episodes:
-            search_episodes[ep.season] = [ep]
-        elif search_mode != 'sponly':
-            search_episodes[ep.season] += [ep]
-
-    for curProvider in providers:
-        threading.currentThread().name = origThreadName + " :: [" + curProvider.name + "]"
-
-        if curProvider.anime_only and not show.is_anime:
-            logger.debug("" + str(show.name) + " is not an anime, skipping")
-            continue
-
-        if curProvider.search_mode != search_mode and not curProvider.search_fallback:
-            logger.debug('Skipping provider because search type does not match and fallback is disabled')
-            continue
-
-        logger.info(_("Performing {episode_or_season} search for {show}").format(
-            episode_or_season=(_('season pack'), _('episode'))[search_mode == 'eponly'], show=show.name))
-
-        curProvider.cache.update_cache()
-        for ep_list in search_episodes.values():
-            for episode in ep_list:
-                try:
-                    curProvider.show = episode.show
-                    if search_mode == 'sponly':
-                        search_params = curProvider.get_season_search_strings(episode)
-                    else:
-                        search_params = curProvider.get_episode_search_strings(episode)
-
-                    searchResults = curProvider.search(search_params[0], ep_obj=episode)
-                except AuthException as error:
-                    logger.warning("Authentication error: {0!r}".format(error))
-                    continue
-                except Exception as error:
-                    logger.exception("Exception while searching {0}. Error: {1!r}".format(curProvider.name, error))
-                    logger.debug(traceback.format_exc())
-                    continue
-
-                didSearch = True
-
-                # make a list of all the results for this provider
-                for curResult in searchResults:
-                    curResult["show"] = episode.show.indexerid
-                    curResult["season"] = episode.season
-                    curResult["episode"] = episode.episode
-                    curResult["provider"] = curProvider.name
-                    try:
-                        parse_result = NameParser(parse_method=('normal', 'anime')[show.is_anime]).parse(curResult["title"])
-                        curResult["quality"] = parse_result.quality
-                        curResult["release_group"] = parse_result.release_group
-                        curResult["version"] = parse_result.version
-                    except (InvalidNameException, InvalidShowException) as error:
-                        logger.debug("{0}".format(error))
-                        continue
-
-                foundResults["results"] += searchResults
-
-    if not didSearch:
-        logger.info("Unable to find any results. Please check the log")
-
-    # Remove provider from thread name before return results
-    threading.currentThread().name = origThreadName
-
-    foundResults["results"].sort(key=lambda d: try_int(d.get('seeders', 0)), reverse=True)
-    return foundResults
