@@ -12,7 +12,7 @@ from sickchill.views.routes import Route
 from . import Config
 
 
-@Route('/config/notifications(/?.*)', name='config:notifications')
+@Route("/config/notifications(/?.*)", name="config:notifications")
 class ConfigNotifications(Config):
     def __init__(self, *args, **kwargs):
         super().__init__(*args, **kwargs)
@@ -21,67 +21,202 @@ class ConfigNotifications(Config):
     def index(self, *args_, **kwargs_):
         t = PageTemplate(rh=self, filename="config_notifications.mako")
 
-        return t.render(submenu=self.ConfigMenu(), title=_('Config - Notifications'),
-                        header=_('Notifications'), topmenu='config',
-                        controller="config", action="notifications")
+        return t.render(
+            submenu=self.ConfigMenu(),
+            title=_("Config - Notifications"),
+            header=_("Notifications"),
+            topmenu="config",
+            controller="config",
+            action="notifications",
+        )
 
     def saveNotifications(
-            self, use_kodi=None, kodi_always_on=None, kodi_notify_onsnatch=None,
-            kodi_notify_ondownload=None,
-            kodi_notify_onsubtitledownload=None, kodi_update_onlyfirst=None,
-            kodi_update_library=None, kodi_update_full=None, kodi_host=None, kodi_username=None,
-            kodi_password=None,
-            use_plex_server=None, plex_notify_onsnatch=None, plex_notify_ondownload=None,
-            plex_notify_onsubtitledownload=None, plex_update_library=None,
-            plex_server_host=None, plex_server_token=None, plex_client_host=None, plex_server_username=None, plex_server_password=None,
-            use_plex_client=None, plex_client_username=None, plex_client_password=None,
-            plex_server_https=None, use_emby=None, emby_host=None, emby_apikey=None,
-            use_growl=None, growl_notify_onsnatch=None, growl_notify_ondownload=None,
-            growl_notify_onsubtitledownload=None, growl_host=None, growl_password=None,
-            use_freemobile=None, freemobile_notify_onsnatch=None, freemobile_notify_ondownload=None,
-            freemobile_notify_onsubtitledownload=None, freemobile_id=None, freemobile_apikey=None,
-            use_telegram=None, telegram_notify_onsnatch=None, telegram_notify_ondownload=None,
-            telegram_notify_onsubtitledownload=None, telegram_id=None, telegram_apikey=None,
-            use_join=None, join_notify_onsnatch=None, join_notify_ondownload=None,
-            join_notify_onsubtitledownload=None, join_id=None, join_apikey=None,
-            use_prowl=None, prowl_notify_onsnatch=None, prowl_notify_ondownload=None,
-            prowl_notify_onsubtitledownload=None, prowl_api=None, prowl_priority=0,
-            prowl_show_list=None, prowl_show=None, prowl_message_title=None,
-            use_twitter=None, twitter_notify_onsnatch=None, twitter_notify_ondownload=None,
-            twitter_notify_onsubtitledownload=None, twitter_usedm=None, twitter_dmto=None,
-            use_twilio=None, twilio_notify_onsnatch=None, twilio_notify_ondownload=None, twilio_notify_onsubtitledownload=None,
-            twilio_phone_sid=None, twilio_account_sid=None, twilio_auth_token=None, twilio_to_number=None,
-            use_boxcar2=None, boxcar2_notify_onsnatch=None, boxcar2_notify_ondownload=None,
-            boxcar2_notify_onsubtitledownload=None, boxcar2_accesstoken=None,
-            use_pushover=None, pushover_notify_onsnatch=None, pushover_notify_ondownload=None,
-            pushover_notify_onsubtitledownload=None, pushover_userkey=None, pushover_apikey=None,
-            pushover_device=None, pushover_sound=None, pushover_priority=0,
-            use_libnotify=None, libnotify_notify_onsnatch=None, libnotify_notify_ondownload=None,
-            libnotify_notify_onsubtitledownload=None,
-            use_nmj=None, nmj_host=None, nmj_database=None, nmj_mount=None, use_synoindex=None,
-            use_nmjv2=None, nmjv2_host=None, nmjv2_dbloc=None, nmjv2_database=None,
-            use_trakt=None, trakt_username=None, trakt_pin=None,
-            trakt_remove_watchlist=None, trakt_sync_watchlist=None, trakt_remove_show_from_sickchill=None, trakt_method_add=None,
-            trakt_start_paused=None, trakt_use_recommended=None, trakt_sync=None, trakt_sync_remove=None,
-            trakt_default_indexer=None, trakt_remove_serieslist=None, trakt_timeout=None, trakt_blacklist_name=None,
-            use_synologynotifier=None, synologynotifier_notify_onsnatch=None,
-            synologynotifier_notify_ondownload=None, synologynotifier_notify_onsubtitledownload=None,
-            use_pytivo=None, pytivo_notify_onsnatch=None, pytivo_notify_ondownload=None,
-            pytivo_notify_onsubtitledownload=None, pytivo_update_library=None,
-            pytivo_host=None, pytivo_share_name=None, pytivo_tivo_name=None,
-            use_pushalot=None, pushalot_notify_onsnatch=None, pushalot_notify_ondownload=None,
-            pushalot_notify_onsubtitledownload=None, pushalot_authorizationtoken=None,
-            use_pushbullet=None, pushbullet_notify_onsnatch=None, pushbullet_notify_ondownload=None,
-            pushbullet_notify_onsubtitledownload=None, pushbullet_api=None, pushbullet_device=None,
-            pushbullet_device_list=None, pushbullet_channel_list=None, pushbullet_channel=None,
-            use_email=None, email_notify_onsnatch=None, email_notify_ondownload=None, email_notify_onpostprocess=None,
-            email_notify_onsubtitledownload=None, email_host=None, email_port=25, email_from=None,
-            email_tls=None, email_user=None, email_password=None, email_list=None, email_subject=None, email_show_list=None,
-            email_show=None, use_slack=False, slack_notify_snatch=None, slack_notify_download=None, slack_notify_subtitledownload=None, slack_webhook=None, slack_icon_emoji=None, use_rocketchat=False, rocketchat_notify_snatch=None, rocketchat_notify_download=None, rocketchat_notify_subtitledownload=None, rocketchat_webhook=None, rocketchat_icon_emoji=None,
-            use_matrix=False, matrix_notify_snatch=None, matrix_notify_download=None, matrix_notify_subtitledownload=None,
-            matrix_api_token=None, matrix_server=None, matrix_room=None,
-            use_discord=False, discord_notify_snatch=None, discord_notify_download=None, discord_webhook=None, discord_name=None,
-            discord_avatar_url=None, discord_tts=False):
+        self,
+        use_kodi=None,
+        kodi_always_on=None,
+        kodi_notify_onsnatch=None,
+        kodi_notify_ondownload=None,
+        kodi_notify_onsubtitledownload=None,
+        kodi_update_onlyfirst=None,
+        kodi_update_library=None,
+        kodi_update_full=None,
+        kodi_host=None,
+        kodi_username=None,
+        kodi_password=None,
+        use_plex_server=None,
+        plex_notify_onsnatch=None,
+        plex_notify_ondownload=None,
+        plex_notify_onsubtitledownload=None,
+        plex_update_library=None,
+        plex_server_host=None,
+        plex_server_token=None,
+        plex_client_host=None,
+        plex_server_username=None,
+        plex_server_password=None,
+        use_plex_client=None,
+        plex_client_username=None,
+        plex_client_password=None,
+        plex_server_https=None,
+        use_emby=None,
+        emby_host=None,
+        emby_apikey=None,
+        use_growl=None,
+        growl_notify_onsnatch=None,
+        growl_notify_ondownload=None,
+        growl_notify_onsubtitledownload=None,
+        growl_host=None,
+        growl_password=None,
+        use_freemobile=None,
+        freemobile_notify_onsnatch=None,
+        freemobile_notify_ondownload=None,
+        freemobile_notify_onsubtitledownload=None,
+        freemobile_id=None,
+        freemobile_apikey=None,
+        use_telegram=None,
+        telegram_notify_onsnatch=None,
+        telegram_notify_ondownload=None,
+        telegram_notify_onsubtitledownload=None,
+        telegram_id=None,
+        telegram_apikey=None,
+        use_join=None,
+        join_notify_onsnatch=None,
+        join_notify_ondownload=None,
+        join_notify_onsubtitledownload=None,
+        join_id=None,
+        join_apikey=None,
+        use_prowl=None,
+        prowl_notify_onsnatch=None,
+        prowl_notify_ondownload=None,
+        prowl_notify_onsubtitledownload=None,
+        prowl_api=None,
+        prowl_priority=0,
+        prowl_show_list=None,
+        prowl_show=None,
+        prowl_message_title=None,
+        use_twitter=None,
+        twitter_notify_onsnatch=None,
+        twitter_notify_ondownload=None,
+        twitter_notify_onsubtitledownload=None,
+        twitter_usedm=None,
+        twitter_dmto=None,
+        use_twilio=None,
+        twilio_notify_onsnatch=None,
+        twilio_notify_ondownload=None,
+        twilio_notify_onsubtitledownload=None,
+        twilio_phone_sid=None,
+        twilio_account_sid=None,
+        twilio_auth_token=None,
+        twilio_to_number=None,
+        use_boxcar2=None,
+        boxcar2_notify_onsnatch=None,
+        boxcar2_notify_ondownload=None,
+        boxcar2_notify_onsubtitledownload=None,
+        boxcar2_accesstoken=None,
+        use_pushover=None,
+        pushover_notify_onsnatch=None,
+        pushover_notify_ondownload=None,
+        pushover_notify_onsubtitledownload=None,
+        pushover_userkey=None,
+        pushover_apikey=None,
+        pushover_device=None,
+        pushover_sound=None,
+        pushover_priority=0,
+        use_libnotify=None,
+        libnotify_notify_onsnatch=None,
+        libnotify_notify_ondownload=None,
+        libnotify_notify_onsubtitledownload=None,
+        use_nmj=None,
+        nmj_host=None,
+        nmj_database=None,
+        nmj_mount=None,
+        use_synoindex=None,
+        use_nmjv2=None,
+        nmjv2_host=None,
+        nmjv2_dbloc=None,
+        nmjv2_database=None,
+        use_trakt=None,
+        trakt_username=None,
+        trakt_pin=None,
+        trakt_remove_watchlist=None,
+        trakt_sync_watchlist=None,
+        trakt_remove_show_from_sickchill=None,
+        trakt_method_add=None,
+        trakt_start_paused=None,
+        trakt_use_recommended=None,
+        trakt_sync=None,
+        trakt_sync_remove=None,
+        trakt_default_indexer=None,
+        trakt_remove_serieslist=None,
+        trakt_timeout=None,
+        trakt_blacklist_name=None,
+        use_synologynotifier=None,
+        synologynotifier_notify_onsnatch=None,
+        synologynotifier_notify_ondownload=None,
+        synologynotifier_notify_onsubtitledownload=None,
+        use_pytivo=None,
+        pytivo_notify_onsnatch=None,
+        pytivo_notify_ondownload=None,
+        pytivo_notify_onsubtitledownload=None,
+        pytivo_update_library=None,
+        pytivo_host=None,
+        pytivo_share_name=None,
+        pytivo_tivo_name=None,
+        use_pushalot=None,
+        pushalot_notify_onsnatch=None,
+        pushalot_notify_ondownload=None,
+        pushalot_notify_onsubtitledownload=None,
+        pushalot_authorizationtoken=None,
+        use_pushbullet=None,
+        pushbullet_notify_onsnatch=None,
+        pushbullet_notify_ondownload=None,
+        pushbullet_notify_onsubtitledownload=None,
+        pushbullet_api=None,
+        pushbullet_device=None,
+        pushbullet_device_list=None,
+        pushbullet_channel_list=None,
+        pushbullet_channel=None,
+        use_email=None,
+        email_notify_onsnatch=None,
+        email_notify_ondownload=None,
+        email_notify_onpostprocess=None,
+        email_notify_onsubtitledownload=None,
+        email_host=None,
+        email_port=25,
+        email_from=None,
+        email_tls=None,
+        email_user=None,
+        email_password=None,
+        email_list=None,
+        email_subject=None,
+        email_show_list=None,
+        email_show=None,
+        use_slack=False,
+        slack_notify_snatch=None,
+        slack_notify_download=None,
+        slack_notify_subtitledownload=None,
+        slack_webhook=None,
+        slack_icon_emoji=None,
+        use_rocketchat=False,
+        rocketchat_notify_snatch=None,
+        rocketchat_notify_download=None,
+        rocketchat_notify_subtitledownload=None,
+        rocketchat_webhook=None,
+        rocketchat_icon_emoji=None,
+        use_matrix=False,
+        matrix_notify_snatch=None,
+        matrix_notify_download=None,
+        matrix_notify_subtitledownload=None,
+        matrix_api_token=None,
+        matrix_server=None,
+        matrix_room=None,
+        use_discord=False,
+        discord_notify_snatch=None,
+        discord_notify_download=None,
+        discord_webhook=None,
+        discord_name=None,
+        discord_avatar_url=None,
+        discord_tts=False,
+    ):
 
         results = []
 
@@ -235,8 +370,7 @@ class ConfigNotifications(Config):
         settings.USE_SYNOLOGYNOTIFIER = config.checkbox_to_value(use_synologynotifier)
         settings.SYNOLOGYNOTIFIER_NOTIFY_ONSNATCH = config.checkbox_to_value(synologynotifier_notify_onsnatch)
         settings.SYNOLOGYNOTIFIER_NOTIFY_ONDOWNLOAD = config.checkbox_to_value(synologynotifier_notify_ondownload)
-        settings.SYNOLOGYNOTIFIER_NOTIFY_ONSUBTITLEDOWNLOAD = config.checkbox_to_value(
-            synologynotifier_notify_onsubtitledownload)
+        settings.SYNOLOGYNOTIFIER_NOTIFY_ONSUBTITLEDOWNLOAD = config.checkbox_to_value(synologynotifier_notify_onsubtitledownload)
 
         config.change_use_trakt(use_trakt)
         settings.TRAKT_USERNAME = trakt_username
@@ -295,9 +429,8 @@ class ConfigNotifications(Config):
         if len(results) > 0:
             for x in results:
                 logger.exception(x)
-            ui.notifications.error(_('Error(s) Saving Configuration'),
-                                   '<br>\n'.join(results))
+            ui.notifications.error(_("Error(s) Saving Configuration"), "<br>\n".join(results))
         else:
-            ui.notifications.message(_('Configuration Saved'), os.path.join(settings.CONFIG_FILE))
+            ui.notifications.message(_("Configuration Saved"), os.path.join(settings.CONFIG_FILE))
 
         return self.redirect("/config/notifications/")
