@@ -13,7 +13,7 @@ from sickchill.views.routes import Route
 from . import Config
 
 
-@Route('/config/postProcessing(/?.*)', name='config:postprocessing')
+@Route("/config/postProcessing(/?.*)", name="config:postprocessing")
 class ConfigPostProcessing(Config):
     def __init__(self, *args, **kwargs):
         super().__init__(*args, **kwargs)
@@ -22,30 +22,61 @@ class ConfigPostProcessing(Config):
     def index(self, *args_, **kwargs_):
         t = PageTemplate(rh=self, filename="config_postProcessing.mako")
 
-        return t.render(submenu=self.ConfigMenu(), title=_('Config - Post Processing'),
-                        header=_('Post Processing'), topmenu='config',
-                        controller="config", action="postProcessing")
+        return t.render(
+            submenu=self.ConfigMenu(),
+            title=_("Config - Post Processing"),
+            header=_("Post Processing"),
+            topmenu="config",
+            controller="config",
+            action="postProcessing",
+        )
 
-    def savePostProcessing(self, kodi_data=None,
-                           mediabrowser_data=None, sony_ps3_data=None,
-                           wdtv_data=None, tivo_data=None, mede8er_data=None,
-                           keep_processed_dir=None, process_method=None, processor_follow_symlinks=None,
-                           del_rar_contents=None, process_automatically=None,
-                           no_delete=None, rename_episodes=None, airdate_episodes=None,
-                           file_timestamp_timezone=None,
-                           unpack=None, unpack_dir=None, unrar_tool=None, unar_tool=None, bsdtar_tool=None,
-                           move_associated_files=None, delete_non_associated_files=None, sync_files=None,
-                           postpone_if_sync_files=None,
-                           allowed_extensions=None, tv_download_dir=None,
-                           create_missing_show_dirs=None, add_shows_wo_dir=None,
-                           extra_scripts=None, nfo_rename=None,
-                           naming_pattern=None, naming_multi_ep=None,
-                           naming_custom_abd=None, naming_anime=None,
-                           naming_abd_pattern=None, naming_strip_year=None,
-                           naming_custom_sports=None, naming_sports_pattern=None,
-                           naming_custom_anime=None, naming_anime_pattern=None,
-                           naming_anime_multi_ep=None, autopostprocessor_frequency=None,
-                           use_icacls=None):
+    def savePostProcessing(
+        self,
+        kodi_data=None,
+        mediabrowser_data=None,
+        sony_ps3_data=None,
+        wdtv_data=None,
+        tivo_data=None,
+        mede8er_data=None,
+        keep_processed_dir=None,
+        process_method=None,
+        processor_follow_symlinks=None,
+        del_rar_contents=None,
+        process_automatically=None,
+        no_delete=None,
+        rename_episodes=None,
+        airdate_episodes=None,
+        file_timestamp_timezone=None,
+        unpack=None,
+        unpack_dir=None,
+        unrar_tool=None,
+        unar_tool=None,
+        bsdtar_tool=None,
+        move_associated_files=None,
+        delete_non_associated_files=None,
+        sync_files=None,
+        postpone_if_sync_files=None,
+        allowed_extensions=None,
+        tv_download_dir=None,
+        create_missing_show_dirs=None,
+        add_shows_wo_dir=None,
+        extra_scripts=None,
+        nfo_rename=None,
+        naming_pattern=None,
+        naming_multi_ep=None,
+        naming_custom_abd=None,
+        naming_anime=None,
+        naming_abd_pattern=None,
+        naming_strip_year=None,
+        naming_custom_sports=None,
+        naming_sports_pattern=None,
+        naming_custom_anime=None,
+        naming_anime_pattern=None,
+        naming_anime_multi_ep=None,
+        autopostprocessor_frequency=None,
+        use_icacls=None,
+    ):
 
         results = []
 
@@ -60,7 +91,7 @@ class ConfigPostProcessing(Config):
 
         unpack = try_int(unpack)
         if unpack == settings.UNPACK_PROCESS_CONTENTS:
-            settings.UNPACK = int(self.isRarSupported() != 'not supported')
+            settings.UNPACK = int(self.isRarSupported() != "not supported")
             if settings.UNPACK != settings.UNPACK_PROCESS_CONTENTS:
                 results.append(_("Unpacking Not Supported, disabling unpack setting"))
         elif unpack in settings.unpackStrings:
@@ -76,7 +107,7 @@ class ConfigPostProcessing(Config):
         settings.PROCESS_METHOD = process_method
         settings.PROCESSOR_FOLLOW_SYMLINKS = config.checkbox_to_value(processor_follow_symlinks)
         settings.DELRARCONTENTS = config.checkbox_to_value(del_rar_contents)
-        settings.EXTRA_SCRIPTS = [x.strip() for x in extra_scripts.split('|') if x.strip()]
+        settings.EXTRA_SCRIPTS = [x.strip() for x in extra_scripts.split("|") if x.strip()]
         settings.RENAME_EPISODES = config.checkbox_to_value(rename_episodes)
         settings.AIRDATE_EPISODES = config.checkbox_to_value(airdate_episodes)
         settings.FILE_TIMESTAMP_TIMEZONE = file_timestamp_timezone
@@ -85,7 +116,7 @@ class ConfigPostProcessing(Config):
         settings.SYNC_FILES = sync_files
         settings.POSTPONE_IF_SYNC_FILES = config.checkbox_to_value(postpone_if_sync_files)
 
-        settings.ALLOWED_EXTENSIONS = ','.join({x.strip() for x in allowed_extensions.split(',') if x.strip()})
+        settings.ALLOWED_EXTENSIONS = ",".join({x.strip() for x in allowed_extensions.split(",") if x.strip()})
         settings.NAMING_CUSTOM_ABD = config.checkbox_to_value(naming_custom_abd)
         settings.NAMING_CUSTOM_SPORTS = config.checkbox_to_value(naming_custom_sports)
         settings.NAMING_CUSTOM_ANIME = config.checkbox_to_value(naming_custom_anime)
@@ -99,12 +130,12 @@ class ConfigPostProcessing(Config):
         settings.METADATA_TIVO = tivo_data
         settings.METADATA_MEDE8ER = mede8er_data
 
-        settings.metadata_provider_dict['KODI'].set_config(settings.METADATA_KODI)
-        settings.metadata_provider_dict['MediaBrowser'].set_config(settings.METADATA_MEDIABROWSER)
-        settings.metadata_provider_dict['Sony PS3'].set_config(settings.METADATA_PS3)
-        settings.metadata_provider_dict['WDTV'].set_config(settings.METADATA_WDTV)
-        settings.metadata_provider_dict['TIVO'].set_config(settings.METADATA_TIVO)
-        settings.metadata_provider_dict['Mede8er'].set_config(settings.METADATA_MEDE8ER)
+        settings.metadata_provider_dict["KODI"].set_config(settings.METADATA_KODI)
+        settings.metadata_provider_dict["MediaBrowser"].set_config(settings.METADATA_MEDIABROWSER)
+        settings.metadata_provider_dict["Sony PS3"].set_config(settings.METADATA_PS3)
+        settings.metadata_provider_dict["WDTV"].set_config(settings.METADATA_WDTV)
+        settings.metadata_provider_dict["TIVO"].set_config(settings.METADATA_TIVO)
+        settings.metadata_provider_dict["Mede8er"].set_config(settings.METADATA_MEDE8ER)
 
         if self.isNamingValid(naming_pattern, naming_multi_ep) != "invalid":
             settings.NAMING_PATTERN = naming_pattern
@@ -136,16 +167,16 @@ class ConfigPostProcessing(Config):
         if results:
             for x in results:
                 logger.warning(x)
-            ui.notifications.error(_('Error(s) Saving Configuration'), '<br>\n'.join(results))
+            ui.notifications.error(_("Error(s) Saving Configuration"), "<br>\n".join(results))
         else:
-            ui.notifications.message(_('Configuration Saved'), os.path.join(settings.CONFIG_FILE))
+            ui.notifications.message(_("Configuration Saved"), os.path.join(settings.CONFIG_FILE))
 
         return self.redirect("/config/postProcessing/")
 
     @staticmethod
     def testNaming(pattern=None, multi=None, abd=False, sports=False, anime_type=None):
         result = naming.test_name(pattern, try_int(multi, None), abd, sports, try_int(anime_type, None))
-        result = os.path.join(result['dir'], result['name'])
+        result = os.path.join(result["dir"], result["name"])
 
         return result
 
@@ -185,5 +216,5 @@ class ConfigPostProcessing(Config):
         """
         check = config.change_unrar_tool(settings.UNRAR_TOOL, settings.UNAR_TOOL, settings.BSDTAR_TOOL)
         if not check:
-            logger.warning('Looks like unrar is not installed, check failed')
-        return ('not supported', 'supported')[check]
+            logger.warning("Looks like unrar is not installed, check failed")
+        return ("not supported", "supported")[check]
