@@ -25,23 +25,23 @@ from sickchill.views.home import Home
 from sickchill.views.routes import Route
 
 
-@Route('/addShows(/?.*)', name='addShows')
+@Route("/addShows(/?.*)", name="addShows")
 class AddShows(Home):
     def __init__(self, *args, **kwargs):
         super().__init__(*args, **kwargs)
 
     def index(self, *args_, **kwargs_):
         t = PageTemplate(rh=self, filename="addShows.mako")
-        return t.render(title=_('Add Shows'), header=_('Add Shows'), topmenu='home', controller="addShows", action="index")
+        return t.render(title=_("Add Shows"), header=_("Add Shows"), topmenu="home", controller="addShows", action="index")
 
     @staticmethod
     def sanitizeFileName(name):
         return sanitize_filename(name)
 
     def searchIndexersForShowName(self, search_term, lang=None, indexer=None):
-        self.set_header('Cache-Control', 'max-age=0,no-cache,no-store')
-        self.set_header('Content-Type', 'application/json')
-        if not lang or lang == 'null':
+        self.set_header("Cache-Control", "max-age=0,no-cache,no-store")
+        self.set_header("Content-Type", "application/json")
+        if not lang or lang == "null":
             lang = settings.INDEXER_DEFAULT_LANGUAGE
 
         search_term = xhtml_unescape(search_term)
@@ -49,13 +49,13 @@ class AddShows(Home):
         searchTerms = [search_term]
 
         # If search term ends with what looks like a year, enclose it in ()
-        matches = re.match(r'^(.+ |)([12][0-9]{3})$', search_term)
+        matches = re.match(r"^(.+ |)([12][0-9]{3})$", search_term)
         if matches:
             searchTerms.append("{0}({1})".format(matches.group(1), matches.group(2)))
 
         for searchTerm in searchTerms:
             # If search term begins with an article, let's also search for it without
-            matches = re.match(r'^(?:a|an|the) (.+)$', searchTerm, re.I)
+            matches = re.match(r"^(?:a|an|the) (.+)$", searchTerm, re.I)
             if matches:
                 searchTerms.append(matches.group(1))
 
@@ -64,8 +64,7 @@ class AddShows(Home):
 
         # Query Indexers for each search term and build the list of results
         for i, j in sickchill.indexer if not int(indexer) else [(int(indexer), None)]:
-            logger.debug("Searching for Show with searchterm(s): {0} on Indexer: {1}".format(
-                searchTerms, 'theTVDB'))
+            logger.debug("Searching for Show with searchterm(s): {0} on Indexer: {1}".format(searchTerms, "theTVDB"))
             for searchTerm in searchTerms:
                 # noinspection PyBroadException
                 try:
@@ -79,12 +78,23 @@ class AddShows(Home):
 
         for i, shows in results.items():
             # noinspection PyUnresolvedReferences
-            final_results.extend({(sickchill.indexer.name(i), i, sickchill.indexer[i].show_url, show['id'],
-                                   show['seriesName'], show['firstAired'], sickchill.tv.Show.find(settings.showList, show['id']) is not None
-                                   ) for show in shows})
+            final_results.extend(
+                {
+                    (
+                        sickchill.indexer.name(i),
+                        i,
+                        sickchill.indexer[i].show_url,
+                        show["id"],
+                        show["seriesName"],
+                        show["firstAired"],
+                        sickchill.tv.Show.find(settings.showList, show["id"]) is not None,
+                    )
+                    for show in shows
+                }
+            )
 
         lang_id = sickchill.indexer.lang_dict()[lang]
-        return json.dumps({'results': final_results, 'langid': lang_id, 'success': len(final_results) > 0})
+        return json.dumps({"results": final_results, "langid": lang_id, "success": len(final_results) > 0})
 
     def massAddTable(self, rootDir=None):
         t = PageTemplate(rh=self, filename="home_massAddTable.mako")
@@ -99,7 +109,7 @@ class AddShows(Home):
         root_dirs = [unquote_plus(xhtml_unescape(x)) for x in root_dirs]
 
         if settings.ROOT_DIRS:
-            default_index = int(settings.ROOT_DIRS.split('|')[0])
+            default_index = int(settings.ROOT_DIRS.split("|")[0])
         else:
             default_index = 0
 
@@ -126,24 +136,24 @@ class AddShows(Home):
                     if not os.path.isdir(cur_path):
                         continue
                     # ignore Synology folders
-                    if cur_file.lower() in ['#recycle', '@eadir']:
+                    if cur_file.lower() in ["#recycle", "@eadir"]:
                         continue
                 except Exception:
                     continue
 
                 cur_dir = {
-                    'dir': cur_path,
-                    'existing_info': (None, None, None),
-                    'display_dir': '<b>' + os.path.dirname(cur_path) + os.sep + '</b>' + os.path.basename(cur_path)
+                    "dir": cur_path,
+                    "existing_info": (None, None, None),
+                    "display_dir": "<b>" + os.path.dirname(cur_path) + os.sep + "</b>" + os.path.basename(cur_path),
                 }
 
                 # see if the folder is in KODI already
                 dirResults = main_db_con.select("SELECT indexer_id FROM tv_shows WHERE location = ? LIMIT 1", [cur_path])
 
                 if dirResults:
-                    cur_dir['added_already'] = True
+                    cur_dir["added_already"] = True
                 else:
-                    cur_dir['added_already'] = False
+                    cur_dir["added_already"] = False
 
                 dir_list.append(cur_dir)
 
@@ -155,10 +165,10 @@ class AddShows(Home):
                             break
 
                 if all((indexer_id, show_name, indexer)):
-                    cur_dir['existing_info'] = (indexer_id, show_name, indexer)
+                    cur_dir["existing_info"] = (indexer_id, show_name, indexer)
 
                 if indexer_id and Show.find(settings.showList, indexer_id):
-                    cur_dir['added_already'] = True
+                    cur_dir["added_already"] = True
         return t.render(dirList=dir_list)
 
     def newShow(self, show_to_add=None, other_shows=None, search_string=None):
@@ -180,11 +190,10 @@ class AddShows(Home):
             if search_string:
                 default_show_name = search_string
             else:
-                default_show_name = ''
+                default_show_name = ""
 
         elif not show_name:
-            default_show_name = re.sub(r' \(\d{4}\)', '',
-                                       os.path.basename(os.path.normpath(show_dir)).replace('.', ' '))
+            default_show_name = re.sub(r" \(\d{4}\)", "", os.path.basename(os.path.normpath(show_dir)).replace(".", " "))
         else:
             default_show_name = show_name
 
@@ -200,13 +209,22 @@ class AddShows(Home):
         provided_indexer = int(indexer or settings.INDEXER_DEFAULT)
 
         return t.render(
-            enable_anime_options=True, use_provided_info=use_provided_info,
-            default_show_name=default_show_name, other_shows=other_shows,
-            provided_show_dir=show_dir, provided_indexer_id=provided_indexer_id,
-            provided_indexer_name=provided_indexer_name, provided_indexer=provided_indexer,
-            whitelist=[], blacklist=[], groups=[],
-            title=_('New Show'), header=_('New Show'), topmenu='home',
-            controller="addShows", action="newShow"
+            enable_anime_options=True,
+            use_provided_info=use_provided_info,
+            default_show_name=default_show_name,
+            other_shows=other_shows,
+            provided_show_dir=show_dir,
+            provided_indexer_id=provided_indexer_id,
+            provided_indexer_name=provided_indexer_name,
+            provided_indexer=provided_indexer,
+            whitelist=[],
+            blacklist=[],
+            groups=[],
+            title=_("New Show"),
+            header=_("New Show"),
+            topmenu="home",
+            controller="addShows",
+            action="newShow",
         )
 
     def trendingShows(self, traktList=None):
@@ -241,8 +259,7 @@ class AddShows(Home):
             page_title = _("Most Anticipated Shows")
 
         t = PageTemplate(rh=self, filename="addShows_trendingShows.mako")
-        return t.render(title=page_title, header=page_title, enable_anime_options=False,
-                        traktList=traktList, controller="addShows", action="trendingShows")
+        return t.render(title=page_title, header=page_title, enable_anime_options=False, traktList=traktList, controller="addShows", action="trendingShows")
 
     def getTrendingShows(self, traktList=None):
         """
@@ -269,9 +286,9 @@ class AddShows(Home):
         elif traktList == "recommended":
             page_url = "recommendations/shows"
         elif traktList == "newshow":
-            page_url = 'calendars/all/shows/new/{0}/30'.format(datetime.date.today().strftime("%Y-%m-%d"))
+            page_url = "calendars/all/shows/new/{0}/30".format(datetime.date.today().strftime("%Y-%m-%d"))
         elif traktList == "newseason":
-            page_url = 'calendars/all/shows/premieres/{0}/30'.format(datetime.date.today().strftime("%Y-%m-%d"))
+            page_url = "calendars/all/shows/premieres/{0}/30".format(datetime.date.today().strftime("%Y-%m-%d"))
         else:
             page_url = "shows/anticipated"
 
@@ -306,9 +323,16 @@ class AddShows(Home):
             popular_shows = None
             imdb_exception = error
 
-        return t.render(title=_("Popular Shows"), header=_("Popular Shows"),
-                        popular_shows=popular_shows, imdb_exception=imdb_exception, imdb_url=imdb_popular.imdb_url,
-                        topmenu="home", controller="addShows", action="popularShows")
+        return t.render(
+            title=_("Popular Shows"),
+            header=_("Popular Shows"),
+            popular_shows=popular_shows,
+            imdb_exception=imdb_exception,
+            imdb_url=imdb_popular.imdb_url,
+            topmenu="home",
+            controller="addShows",
+            action="popularShows",
+        )
 
     def favoriteShows(self):
         """
@@ -317,9 +341,9 @@ class AddShows(Home):
         t = PageTemplate(rh=self, filename="addShows_favoriteShows.mako")
         e = None
 
-        if self.get_body_argument('submit', None):
-            tvdb_user = self.get_body_argument('tvdb_user')
-            tvdb_user_key = filters.unhide(settings.TVDB_USER_KEY, self.get_body_argument('tvdb_user_key'))
+        if self.get_body_argument("submit", None):
+            tvdb_user = self.get_body_argument("tvdb_user")
+            tvdb_user_key = filters.unhide(settings.TVDB_USER_KEY, self.get_body_argument("tvdb_user_key"))
             if tvdb_user and tvdb_user_key:
                 if tvdb_user != settings.TVDB_USER or tvdb_user_key != settings.TVDB_USER_KEY:
                     favorites.test_user_key(tvdb_user, tvdb_user_key, 1)
@@ -331,53 +355,74 @@ class AddShows(Home):
             logger.warning(_("Could not get favorite shows: {0}").format(str(e)))
             favorite_shows = None
 
-        return t.render(title=_("Favorite Shows"), header=_("Favorite Shows"),
-                        favorite_shows=favorite_shows, favorites_exception=e,
-                        topmenu="home",
-                        controller="addShows", action="popularShows")
+        return t.render(
+            title=_("Favorite Shows"),
+            header=_("Favorite Shows"),
+            favorite_shows=favorite_shows,
+            favorites_exception=e,
+            topmenu="home",
+            controller="addShows",
+            action="popularShows",
+        )
 
     def addShowToBlacklist(self):
         # URL parameters
 
-        indexer_id = self.get_query_argument('indexer_id')
+        indexer_id = self.get_query_argument("indexer_id")
         if not indexer_id:
             raise HTTPError(404)
 
-        data = {'shows': [{'ids': {'tvdb': indexer_id}}]}
+        data = {"shows": [{"ids": {"tvdb": indexer_id}}]}
 
         trakt_api = TraktAPI(settings.SSL_VERIFY, settings.TRAKT_TIMEOUT)
 
-        trakt_api.traktRequest("users/" + settings.TRAKT_USERNAME + "/lists/" + settings.TRAKT_BLACKLIST_NAME + "/items", data, method='POST')
+        trakt_api.traktRequest("users/" + settings.TRAKT_USERNAME + "/lists/" + settings.TRAKT_BLACKLIST_NAME + "/items", data, method="POST")
 
-        return self.redirect('/addShows/trendingShows/')
+        return self.redirect("/addShows/trendingShows/")
 
     def existingShows(self):
         """
         Prints out the page to add existing shows from a root dir
         """
         t = PageTemplate(rh=self, filename="addShows_addExistingShow.mako")
-        return t.render(enable_anime_options=False, title=_('Existing Show'),
-                        header=_('Existing Show'), topmenu="home",
-                        controller="addShows", action="addExistingShow")
+        return t.render(
+            enable_anime_options=False, title=_("Existing Show"), header=_("Existing Show"), topmenu="home", controller="addShows", action="addExistingShow"
+        )
 
     # noinspection PyUnusedLocal
     def addShowByID(
-            self, indexer_id, show_name, indexer="TVDB", which_series=None,
-            indexer_lang=None, root_dir=None, default_status=None,
-            quality_preset=None, any_qualities=None, best_qualities=None,
-            season_folders=None, subtitles=None, full_show_path=None,
-            other_shows=None, skip_show=None, provided_indexer=None,
-            anime=None, scene=None, blacklist=None, whitelist=None,
-            default_status_after=None, default_season_folders=None,
-            configure_show_options=None):
+        self,
+        indexer_id,
+        show_name,
+        indexer="TVDB",
+        which_series=None,
+        indexer_lang=None,
+        root_dir=None,
+        default_status=None,
+        quality_preset=None,
+        any_qualities=None,
+        best_qualities=None,
+        season_folders=None,
+        subtitles=None,
+        full_show_path=None,
+        other_shows=None,
+        skip_show=None,
+        provided_indexer=None,
+        anime=None,
+        scene=None,
+        blacklist=None,
+        whitelist=None,
+        default_status_after=None,
+        default_season_folders=None,
+        configure_show_options=None,
+    ):
 
         if indexer != "TVDB":
             indexer_id = helpers.tvdbid_from_remote_id(indexer_id, indexer.upper())
             if not indexer_id:
                 logger.info("Unable to to find tvdb ID to add {0}".format(show_name))
                 ui.notifications.error(
-                    "Unable to add {0}".format(show_name),
-                    "Could not add {0}.  We were unable to locate the tvdb id at this time.".format(show_name)
+                    "Unable to add {0}".format(show_name), "Could not add {0}.  We were unable to locate the tvdb id at this time.".format(show_name)
                 )
                 return
 
@@ -387,8 +432,8 @@ class AddShows(Home):
             return
 
         # Sanitize the parameter anyQualities and bestQualities. As these would normally be passed as lists
-        any_qualities = any_qualities.split(',') if any_qualities else []
-        best_qualities = best_qualities.split(',') if best_qualities else []
+        any_qualities = any_qualities.split(",") if any_qualities else []
+        best_qualities = best_qualities.split(",") if best_qualities else []
 
         # If configure_show_options is enabled let's use the provided settings
         if config.checkbox_to_value(configure_show_options):
@@ -429,7 +474,7 @@ class AddShows(Home):
             default_status_after = settings.STATUS_DEFAULT_AFTER
 
             if settings.ROOT_DIRS:
-                root_dirs = settings.ROOT_DIRS.split('|')
+                root_dirs = settings.ROOT_DIRS.split("|")
                 location = root_dirs[int(root_dirs[0]) + 1]
             else:
                 location = None
@@ -442,25 +487,56 @@ class AddShows(Home):
         show_dir = None
 
         if not show_name:
-            ui.notifications.error(_('Unable to add show'))
-            return self.redirect('/home/')
+            ui.notifications.error(_("Unable to add show"))
+            return self.redirect("/home/")
 
         # add the show
         settings.showQueueScheduler.action.add_show(
-            indexer=1, indexer_id=indexer_id, showDir=show_dir, default_status=default_status, quality=quality,
-            season_folders=season_folders, lang=indexer_lang, subtitles=subtitles, subtitles_sr_metadata=None,
-            anime=anime, scene=scene, paused=None, blacklist=blacklist, whitelist=whitelist,
-            default_status_after=default_status_after, root_dir=location)
+            indexer=1,
+            indexer_id=indexer_id,
+            showDir=show_dir,
+            default_status=default_status,
+            quality=quality,
+            season_folders=season_folders,
+            lang=indexer_lang,
+            subtitles=subtitles,
+            subtitles_sr_metadata=None,
+            anime=anime,
+            scene=scene,
+            paused=None,
+            blacklist=blacklist,
+            whitelist=whitelist,
+            default_status_after=default_status_after,
+            root_dir=location,
+        )
 
-        ui.notifications.message(_('Show added'), _('Adding the specified show {show_name}').format(show_name=show_name))
+        ui.notifications.message(_("Show added"), _("Adding the specified show {show_name}").format(show_name=show_name))
 
         # done adding show
-        return self.redirect('/home/')
+        return self.redirect("/home/")
 
-    def addNewShow(self, whichSeries=None, indexerLang=None, rootDir=None, defaultStatus=None,
-                   quality_preset=None, anyQualities=None, bestQualities=None, season_folders=None, subtitles=None,
-                   subtitles_sr_metadata=None, fullShowPath=None, other_shows=None, skipShow=None, providedIndexer=None,
-                   anime=None, scene=None, blacklist=None, whitelist=None, defaultStatusAfter=None):
+    def addNewShow(
+        self,
+        whichSeries=None,
+        indexerLang=None,
+        rootDir=None,
+        defaultStatus=None,
+        quality_preset=None,
+        anyQualities=None,
+        bestQualities=None,
+        season_folders=None,
+        subtitles=None,
+        subtitles_sr_metadata=None,
+        fullShowPath=None,
+        other_shows=None,
+        skipShow=None,
+        providedIndexer=None,
+        anime=None,
+        scene=None,
+        blacklist=None,
+        whitelist=None,
+        defaultStatusAfter=None,
+    ):
         """
         Receive tvdb id, dir, and other options and create a show from them. If extra show dirs are
         provided then it forwards back to newShow, if not it goes to /home.
@@ -478,7 +554,7 @@ class AddShows(Home):
         def finishAddShow():
             # if there are no extra shows then go home
             if not other_shows:
-                return self.redirect('/home/')
+                return self.redirect("/home/")
 
             # peel off the next one
             next_show_dir = other_shows[0]
@@ -494,15 +570,16 @@ class AddShows(Home):
         # sanity check on our inputs
         if (not rootDir and not fullShowPath) or not whichSeries:
             return _("Missing params, no Indexer ID or folder: {show_to_add} and {root_dir}/{show_path}").format(
-                show_to_add=whichSeries, root_dir=rootDir, show_path=fullShowPath)
+                show_to_add=whichSeries, root_dir=rootDir, show_path=fullShowPath
+            )
 
         # figure out what show we're adding and where
-        series_pieces = whichSeries.split('|')
+        series_pieces = whichSeries.split("|")
         if (whichSeries and rootDir) or (whichSeries and fullShowPath and len(series_pieces) > 1):
             if len(series_pieces) < 6:
                 logger.error("Unable to add show due to show selection. Not enough arguments: {0}".format((repr(series_pieces))))
                 ui.notifications.error(_("Unknown error. Unable to add show due to problem with show selection."))
-                return self.redirect('/addShows/existingShows/')
+                return self.redirect("/addShows/existingShows/")
 
             indexer = int(series_pieces[1])
             indexer_id = int(series_pieces[3])
@@ -526,11 +603,11 @@ class AddShows(Home):
             s = sickchill.indexer.series_by_id(indexerid=indexer_id, indexer=indexer, language=indexerLang)
             if settings.ADD_SHOWS_WITH_YEAR and s.firstAired:
                 try:
-                    year = '({0})'.format(dateutil.parser.parse(s.firstAired).year)
+                    year = "({0})".format(dateutil.parser.parse(s.firstAired).year)
                     if year not in folder_name:
-                        folder_name = '{0} {1}'.format(s.seriesName, year)
+                        folder_name = "{0} {1}".format(s.seriesName, year)
                 except (TypeError, ValueError):
-                    logger.info(_('Could not append the show year folder for the show: {0}').format(folder_name))
+                    logger.info(_("Could not append the show year folder for the show: {0}").format(folder_name))
 
             show_dir = os.path.join(rootDir, sanitize_filename(xhtml_unescape(folder_name)))
             extra_check_dir = os.path.join(rootDir, sanitize_filename(xhtml_unescape(show_name)))
@@ -538,7 +615,7 @@ class AddShows(Home):
         # blanket policy - if the dir exists you should have used "add existing show" numbnuts
         if (os.path.isdir(show_dir) or os.path.isdir(extra_check_dir)) and not fullShowPath:
             ui.notifications.error(_("Unable to add show"), _("Folder {show_dir} exists already").format(show_dir=show_dir))
-            return self.redirect('/addShows/existingShows/')
+            return self.redirect("/addShows/existingShows/")
 
         # don't create show dir if config says not to
         if settings.ADD_SHOWS_WO_DIR:
@@ -547,8 +624,7 @@ class AddShows(Home):
             dir_exists = helpers.makeDir(show_dir)
             if not dir_exists:
                 logger.exception("Unable to create the folder " + show_dir + ", can't add the show")
-                ui.notifications.error(_("Unable to add show"),
-                                       _("Unable to create the folder {show_dir}, can't add the show").format(show_dir=show_dir))
+                ui.notifications.error(_("Unable to add show"), _("Unable to create the folder {show_dir}, can't add the show").format(show_dir=show_dir))
                 # Don't redirect to default page because user wants to see the new show
                 return self.redirect("/home/")
             else:
@@ -578,11 +654,24 @@ class AddShows(Home):
 
         # add the show
         settings.showQueueScheduler.action.add_show(
-            indexer, indexer_id, showDir=show_dir, default_status=int(defaultStatus), quality=newQuality,
-            season_folders=season_folders, lang=indexerLang, subtitles=subtitles, subtitles_sr_metadata=subtitles_sr_metadata,
-            anime=anime, scene=scene, paused=None, blacklist=blacklist, whitelist=whitelist,
-            default_status_after=int(defaultStatusAfter), root_dir=rootDir)
-        ui.notifications.message(_('Show added'), _('Adding the specified show into {show_dir}').format(show_dir=show_dir))
+            indexer,
+            indexer_id,
+            showDir=show_dir,
+            default_status=int(defaultStatus),
+            quality=newQuality,
+            season_folders=season_folders,
+            lang=indexerLang,
+            subtitles=subtitles,
+            subtitles_sr_metadata=subtitles_sr_metadata,
+            anime=anime,
+            scene=scene,
+            paused=None,
+            blacklist=blacklist,
+            whitelist=whitelist,
+            default_status_after=int(defaultStatusAfter),
+            root_dir=rootDir,
+        )
+        ui.notifications.message(_("Show added"), _("Adding the specified show into {show_dir}").format(show_dir=show_dir))
 
         return finishAddShow()
 
@@ -590,7 +679,7 @@ class AddShows(Home):
     def split_extra_show(extra_show):
         if not extra_show:
             return None, None, None, None
-        split_vals = extra_show.split('|')
+        split_vals = extra_show.split("|")
         if len(split_vals) < 4:
             indexer = split_vals[0]
             show_dir = split_vals[1]
@@ -598,7 +687,7 @@ class AddShows(Home):
         indexer = split_vals[0]
         show_dir = split_vals[1]
         indexer_id = split_vals[2]
-        show_name = '|'.join(split_vals[3:])
+        show_name = "|".join(split_vals[3:])
 
         return indexer, show_dir, indexer_id, show_name
 
@@ -620,11 +709,11 @@ class AddShows(Home):
         dirs_only = []
         # separate all the ones with Indexer IDs
         for cur_dir in shows_to_add:
-            if '|' in cur_dir:
-                split_vals = cur_dir.split('|')
+            if "|" in cur_dir:
+                split_vals = cur_dir.split("|")
                 if len(split_vals) < 3:
                     dirs_only.append(cur_dir)
-            if '|' not in cur_dir:
+            if "|" not in cur_dir:
                 dirs_only.append(cur_dir)
             else:
                 indexer, show_dir, indexer_id, show_name = self.split_extra_show(cur_dir)
@@ -646,24 +735,25 @@ class AddShows(Home):
             if indexer is not None and indexer_id is not None:
                 # add the show
                 settings.showQueueScheduler.action.add_show(
-                    indexer, indexer_id, show_dir,
+                    indexer,
+                    indexer_id,
+                    show_dir,
                     default_status=settings.STATUS_DEFAULT,
                     quality=settings.QUALITY_DEFAULT,
                     season_folders=settings.SEASON_FOLDERS_DEFAULT,
                     subtitles=settings.SUBTITLES_DEFAULT,
                     anime=settings.ANIME_DEFAULT,
                     scene=settings.SCENE_DEFAULT,
-                    default_status_after=settings.STATUS_DEFAULT_AFTER
+                    default_status_after=settings.STATUS_DEFAULT_AFTER,
                 )
                 num_added += 1
 
         if num_added:
-            ui.notifications.message(_("Shows Added"),
-                                     _("Automatically added {num_shows} from their existing metadata files").format(num_shows=str(num_added)))
+            ui.notifications.message(_("Shows Added"), _("Automatically added {num_shows} from their existing metadata files").format(num_shows=str(num_added)))
 
         # if we're done then go home
         if not dirs_only:
-            return self.redirect('/home/')
+            return self.redirect("/home/")
 
         # for the remaining shows we need to prompt for each one, so forward this on to the newShow page
         return self.newShow(dirs_only[0], dirs_only[1:])
