@@ -4,11 +4,11 @@ Tests for SickChill show
 
 import unittest
 
-from .coming_episodes_tests import ComingEpisodesTests
-from .history_tests import HistoryTests
-from .show_tests import ShowTests
+from .test_coming_episodes import ComingEpisodesTests
+from .test_history import HistoryTests
+from .test_show import ShowTests
 
-if __name__ == '__main__':
+if __name__ == "__main__":
     print('=====> Running all test in "sickchill_tests.show" <=====')
 
     TEST_CLASSES = [
