@@ -4,10 +4,10 @@ Tests for SickChill system
 
 import unittest
 
-from .restart_tests import RestartTests
-from .shutdown_tests import ShutdownTests
+from .test_restart import RestartTests
+from .test_shutdown import ShutdownTests
 
-if __name__ == '__main__':
+if __name__ == "__main__":
     print('=====> Running all test in "sickchill_tests.system" <=====')
 
     TEST_CLASSES = [
